#ifndef lint
static char const 
yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.28 2000/01/17 02:04:06 bde Exp $";
#endif
#include <stdlib.h>
#define YYBYACC 1
#define YYMAJOR 1
#define YYMINOR 9
#define YYLEX yylex()
#define YYEMPTY -1
#define yyclearin (yychar=(YYEMPTY))
#define yyerrok (yyerrflag=0)
#define YYRECOVERING() (yyerrflag!=0)
static int yygrowstack();
#define YYPREFIX "yy"
#line 2 "cfg-grammar.y"

#include "syslog-ng.h"
#include "cfg.h"
#include "sgroup.h"
#include "dgroup.h"
#include "center.h"
#include "filter.h"
#include "templates.h"
#include "logreader.h"
#include "logparser.h"
#include "logrewrite.h"

#if ENABLE_SSL /* BEGIN MARK: tls */
#include "tlscontext.h"
#endif         /* END MARK */

#include "affile.h"
#include "afinter.h"
#include "afsocket.h"
#include "afinet.h"
#include "afunix.h"
#include "afstreams.h"
#include "afuser.h"
#include "afprog.h"
#if ENABLE_SQL
#include "afsql.h"
#endif

#include "messages.h"

#include "syslog-names.h"

#include <netinet/in.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

/* FIXME: the lexer allocates strings with strdup instead of g_strdup,
 * therefore there are unnecessary g_strdup/free pairs in the grammar. These
 * should be removed. */

void yyerror(char *msg);
int yylex();

LogDriver *last_driver;
LogReaderOptions *last_reader_options;
LogWriterOptions *last_writer_options;
LogTemplate *last_template;
SocketOptions *last_sock_options;
LogParser *last_parser;
FilterRE *last_re_filter;
LogRewrite *last_rewrite;
gint last_addr_family = AF_INET;

#if ENABLE_SSL
TLSContext *last_tls_context;
#endif


#if ! ENABLE_IPV6
#undef AF_INET6
#define AF_INET6 0; g_assert_not_reached()

#endif

static struct _LogTemplate *
cfg_check_inline_template(GlobalConfig *cfg, const gchar *template_or_name)
{
  struct _LogTemplate *template = cfg_lookup_template(configuration, template_or_name);
  if (template == NULL)
    {
      template = log_template_new(NULL, template_or_name); 
      template->def_inline = TRUE;
    }
  return template;
}

static gboolean
cfg_check_template(LogTemplate *template)
{
  GError *error = NULL;
  if (!log_template_compile(template, &error))
    {
      msg_error("Error compiling template",
                evt_tag_str("template", template->template),
                evt_tag_str("error", error->message),
                NULL);
      g_clear_error(&error);
      return FALSE;
    }
  return TRUE;
}

#line 97 "cfg-grammar.y"
typedef union {
	gint64 num;
	char *cptr;
	void *ptr;
	FilterExprNode *node;
} YYSTYPE;
#line 118 "cfg-grammar.c"
#define YYERRCODE 256
#define KW_SOURCE 257
#define KW_FILTER 258
#define KW_PARSER 259
#define KW_DESTINATION 260
#define KW_LOG 261
#define KW_OPTIONS 262
#define KW_INTERNAL 263
#define KW_FILE 264
#define KW_PIPE 265
#define KW_UNIX_STREAM 266
#define KW_UNIX_DGRAM 267
#define KW_TCP 268
#define KW_UDP 269
#define KW_TCP6 270
#define KW_UDP6 271
#define KW_USERTTY 272
#define KW_DOOR 273
#define KW_SUN_STREAMS 274
#define KW_PROGRAM 275
#define KW_SQL 276
#define KW_TYPE 277
#define KW_COLUMNS 278
#define KW_INDEXES 279
#define KW_VALUES 280
#define KW_PASSWORD 281
#define KW_DATABASE 282
#define KW_USERNAME 283
#define KW_TABLE 284
#define KW_ENCODING 285
#define KW_DELIMITERS 286
#define KW_QUOTES 287
#define KW_QUOTE_PAIRS 288
#define KW_NULL 289
#define KW_SYSLOG 290
#define KW_TRANSPORT 291
#define KW_FSYNC 292
#define KW_MARK_FREQ 293
#define KW_STATS_FREQ 294
#define KW_STATS_LEVEL 295
#define KW_FLUSH_LINES 296
#define KW_SUPPRESS 297
#define KW_FLUSH_TIMEOUT 298
#define KW_LOG_MSG_SIZE 299
#define KW_FILE_TEMPLATE 300
#define KW_PROTO_TEMPLATE 301
#define KW_CHAIN_HOSTNAMES 302
#define KW_NORMALIZE_HOSTNAMES 303
#define KW_KEEP_HOSTNAME 304
#define KW_CHECK_HOSTNAME 305
#define KW_BAD_HOSTNAME 306
#define KW_KEEP_TIMESTAMP 307
#define KW_USE_DNS 308
#define KW_USE_FQDN 309
#define KW_DNS_CACHE 310
#define KW_DNS_CACHE_SIZE 311
#define KW_DNS_CACHE_EXPIRE 312
#define KW_DNS_CACHE_EXPIRE_FAILED 313
#define KW_DNS_CACHE_HOSTS 314
#define KW_PERSIST_ONLY 315
#define KW_TZ_CONVERT 316
#define KW_TS_FORMAT 317
#define KW_FRAC_DIGITS 318
#define KW_LOG_FIFO_SIZE 319
#define KW_LOG_DISK_FIFO_SIZE 320
#define KW_LOG_FETCH_LIMIT 321
#define KW_LOG_IW_SIZE 322
#define KW_LOG_PREFIX 323
#define KW_PROGRAM_OVERRIDE 324
#define KW_HOST_OVERRIDE 325
#define KW_THROTTLE 326
#define KW_TLS 327
#define KW_PEER_VERIFY 328
#define KW_KEY_FILE 329
#define KW_CERT_FILE 330
#define KW_CA_DIR 331
#define KW_CRL_DIR 332
#define KW_TRUSTED_KEYS 333
#define KW_TRUSTED_DN 334
#define KW_FLAGS 335
#define KW_PAD_SIZE 336
#define KW_TIME_ZONE 337
#define KW_RECV_TIME_ZONE 338
#define KW_SEND_TIME_ZONE 339
#define KW_TIME_REOPEN 340
#define KW_TIME_REAP 341
#define KW_TIME_SLEEP 342
#define KW_TMPL_ESCAPE 343
#define KW_OPTIONAL 344
#define KW_CREATE_DIRS 345
#define KW_OWNER 346
#define KW_GROUP 347
#define KW_PERM 348
#define KW_DIR_OWNER 349
#define KW_DIR_GROUP 350
#define KW_DIR_PERM 351
#define KW_TEMPLATE 352
#define KW_TEMPLATE_ESCAPE 353
#define KW_FOLLOW_FREQ 354
#define KW_OVERWRITE_IF_OLDER 355
#define KW_KEEP_ALIVE 356
#define KW_MAX_CONNECTIONS 357
#define KW_LOCALIP 358
#define KW_IP 359
#define KW_LOCALPORT 360
#define KW_PORT 361
#define KW_DESTPORT 362
#define KW_FRAMED 363
#define KW_IP_TTL 364
#define KW_SO_BROADCAST 365
#define KW_IP_TOS 366
#define KW_SO_SNDBUF 367
#define KW_SO_RCVBUF 368
#define KW_SO_KEEPALIVE 369
#define KW_SPOOF_SOURCE 370
#define KW_USE_TIME_RECVD 371
#define KW_FACILITY 372
#define KW_LEVEL 373
#define KW_HOST 374
#define KW_MATCH 375
#define KW_MESSAGE 376
#define KW_NETMASK 377
#define KW_CSV_PARSER 378
#define KW_VALUE 379
#define KW_DB_PARSER 380
#define KW_REWRITE 381
#define KW_SET 382
#define KW_SUBST 383
#define KW_YES 384
#define KW_NO 385
#define KW_GC_IDLE_THRESHOLD 386
#define KW_GC_BUSY_THRESHOLD 387
#define KW_COMPRESS 388
#define KW_MAC 389
#define KW_AUTH 390
#define KW_ENCRYPT 391
#define KW_IFDEF 392
#define KW_ENDIF 393
#define DOTDOT 394
#define IDENTIFIER 395
#define NUMBER 396
#define STRING 397
#define KW_OR 398
#define KW_AND 399
#define KW_NOT 400
const short yylhs[] = {                                        -1,
    0,   73,   73,   74,   74,   74,   74,   74,   74,   74,
   74,    1,    2,    3,    4,    5,    6,   47,   47,   48,
   48,   48,   48,   48,   49,   49,   50,   51,   51,   52,
   52,    7,   75,    8,   76,   76,   77,   77,   78,   78,
   78,   78,   79,   79,   79,    9,    9,   10,   10,   10,
   10,   10,   10,   11,   12,   12,   81,   13,   80,   80,
   82,   82,   82,   85,   14,   84,   84,   15,   15,   87,
   15,   88,   15,   89,   15,   90,   15,   92,   16,   93,
   17,   91,   91,   94,   94,   94,   94,   94,   94,   94,
   96,   18,   95,   95,   97,   98,   98,   98,   98,   98,
   98,  100,   19,   99,   99,  101,  102,  101,  101,   22,
   22,  104,   20,  106,   21,  105,  105,  107,  107,  107,
  107,  107,  108,  107,  107,   26,  109,   27,   23,   23,
   23,  111,   24,  110,  110,  112,  112,  112,   86,   86,
   83,   83,   83,   83,   83,   83,   83,   83,   83,   83,
   83,   83,   83,   83,   83,   83,   83,   83,   83,   25,
   25,   28,   28,   29,   29,   29,   29,   29,   29,   29,
   30,  114,   31,  113,  113,  115,  115,  115,  115,  115,
  115,  115,  115,  115,  115,  115,   32,  118,   33,  117,
  117,  119,  119,  119,  119,   34,   34,  120,   34,  121,
   34,  122,   34,  123,   34,  125,   35,  126,   36,  124,
  124,  127,  127,  127,  130,   37,  129,  129,  132,  132,
  132,  132,  132,  132,  132,  131,  131,  134,   38,  133,
  133,  135,  136,  135,  128,   39,  138,   40,  137,  137,
  139,  139,  139,  139,  139,  139,  140,  139,   41,   42,
  142,   43,   44,  144,   45,  143,  143,  145,  145,  145,
  145,  145,  145,  145,  145,  145,  145,  145,  145,  145,
  145,  145,  145,  141,  141,  116,  116,  116,  116,  116,
  116,  116,  116,  116,  116,  116,   46,   46,   53,   53,
   54,   54,   54,   54,   54,   54,   54,   54,   54,   54,
   54,   54,   54,   54,   54,   54,   54,   54,   54,   54,
   54,   54,   54,   54,   54,   54,   54,   54,   54,   54,
   54,   54,   54,   54,   54,   54,   54,   54,   54,   54,
   54,  103,  103,  146,  146,  146,  146,  146,  146,  146,
  146,  146,   55,   55,   55,   55,   55,   56,   56,   56,
   56,   56,  148,   56,  149,   56,  151,   56,  152,   56,
  153,   56,  150,  150,  154,  154,  147,  147,  155,  155,
   66,   66,   57,   57,   58,   59,   59,   60,   60,  157,
   61,  159,   61,  158,  158,  160,  161,  161,  162,  156,
  156,  163,  163,  163,  163,  163,  163,   62,   62,   64,
   65,   65,  165,   63,  166,   63,  164,  164,  167,  167,
  167,   67,   67,   67,   68,   68,   69,   69,   70,   70,
   71,   72,   72,
};
const short yylen[] = {                                         2,
    1,    3,    0,    2,    2,    2,    2,    2,    2,    2,
    2,    4,    5,    5,    4,    4,    5,    3,    0,    4,
    4,    4,    4,    4,    2,    0,    7,    5,    0,    2,
    0,    3,    0,    5,    3,    0,    4,    4,    4,    4,
    4,    4,    1,    4,    4,    3,    0,    1,    1,    1,
    1,    1,    1,    3,    4,    4,    0,    3,    2,    0,
    1,    4,    4,    0,    3,    4,    1,    4,    4,    0,
    5,    0,    5,    0,    5,    0,    5,    0,    3,    0,
    3,    2,    0,    4,    4,    4,    4,    1,    1,    1,
    0,    2,    2,    0,    1,    4,    4,    4,    4,    1,
    1,    0,    2,    2,    0,    1,    0,    5,    1,    4,
    4,    0,    5,    0,    2,    2,    0,    1,    4,    4,
    4,    4,    0,    5,    1,    4,    0,    3,    1,    4,
    1,    0,    3,    2,    0,    1,    4,    1,    2,    0,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    2,
    0,    3,    0,    1,    1,    1,    1,    1,    1,    1,
    4,    0,    3,    2,    0,    1,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    0,    3,    2,
    0,    1,    4,    4,    4,    4,    4,    0,    5,    0,
    5,    0,    5,    0,    5,    0,    3,    0,    3,    2,
    0,    1,    1,    1,    0,    3,    2,    0,    4,    4,
    4,    4,    1,    1,    1,    1,    4,    0,    3,    2,
    0,    1,    0,    5,    4,    4,    0,    3,    2,    0,
    1,    4,    4,    4,    4,    4,    0,    5,    4,    4,
    0,    3,    4,    0,    2,    2,    0,    1,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    1,    2,    0,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    2,    0,    3,    0,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    2,    0,    1,    4,    4,    4,    4,    4,    4,
    4,    1,    1,    2,    3,    3,    3,    4,    4,    4,
    4,    4,    0,    6,    0,    6,    0,    6,    0,    6,
    0,    6,    2,    0,    1,    4,    2,    0,    4,    4,
    2,    0,    2,    1,    1,    2,    1,    3,    1,    0,
    5,    0,    5,    2,    0,    4,    1,    4,    4,    2,
    0,    1,    4,    4,    4,    4,    4,    2,    0,    1,
    2,    0,    0,    8,    0,    7,    2,    0,    4,    4,
    4,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    2,    0,
};
const short yydefred[] = {                                      0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    1,
    0,  417,  418,    4,    0,    7,    0,    8,    0,    5,
    0,    0,    6,    0,   11,   10,   33,    9,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    2,    0,    0,    0,
    0,    0,   72,   70,   76,   74,    0,    0,  112,  129,
  131,    0,    0,   48,   49,   50,   51,   52,   53,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  343,    0,    0,    0,    0,    0,    0,    0,  200,
  198,  204,  202,    0,    0,    0,    0,    0,    0,  164,
  165,  166,  169,  167,  168,  170,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   32,    0,    0,    0,
    0,    0,    0,  400,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   12,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  344,    0,    0,
    0,    0,  380,  382,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  254,    0,   16,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   25,   18,    0,
    0,    0,    0,    0,    0,    0,    0,  412,  413,  414,
    0,    0,    0,    0,    0,    0,  416,  415,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  420,  419,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  289,    0,    0,
    0,    0,    0,    0,  401,   15,   54,    0,   57,    0,
   64,    0,   80,    0,   78,  102,   91,  102,   91,    0,
  132,    0,  127,  114,   46,  361,    0,  353,    0,    0,
    0,  375,    0,    0,    0,  355,  357,  359,    0,  347,
    0,  346,   13,    0,    0,   14,    0,  172,    0,  188,
    0,  208,    0,  206,    0,    0,    0,    0,    0,    0,
  251,    0,    0,    0,  237,  162,   20,   21,   22,   24,
   23,    0,    0,   17,  291,  292,  293,  294,  295,  310,
  328,  329,  296,  297,  298,  299,  300,  311,  303,  302,
  323,  324,  325,  326,  327,  312,  313,  307,  309,  308,
  330,  331,  304,  305,  306,  316,  317,  318,  319,  320,
  321,  322,  301,  315,  314,    0,    0,   34,    0,  405,
    0,   55,    0,   56,    0,   69,    0,   68,    0,    0,
    0,    0,    0,    0,    0,  130,    0,  126,    0,    0,
    0,    0,  351,    0,  349,  348,  373,  350,  376,    0,
    0,    0,    0,  352,    0,    0,    0,    0,    0,    0,
    0,    0,  392,  387,    0,    0,    0,    0,  171,    0,
  187,    0,  197,  211,  196,  211,    0,  228,    0,  215,
    0,    0,  249,  250,    0,  253,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  258,  273,  255,    0,  236,  240,    0,    0,    0,    0,
    0,   35,    0,  403,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   58,    0,   61,    0,    0,
   65,   67,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   88,   90,   89,   81,    0,   79,   73,  107,
    0,    0,    0,    0,    0,    0,  109,   43,  101,  100,
  106,  103,    0,   71,   92,    0,   95,   77,   75,    0,
  136,  138,  133,    0,  128,  113,    0,  123,  125,  118,
  115,    0,    0,    0,    0,    0,    0,  378,    0,    0,
    0,    0,  365,    0,    0,    0,    0,    0,    0,    0,
    0,  381,  390,    0,  383,  384,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  173,    0,  176,
    0,    0,    0,  192,  189,    0,    0,    0,  201,  231,
  199,  218,  205,  203,    0,  252,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  256,    0,    0,    0,   30,   37,   38,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   59,    0,  139,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   82,    0,    0,
    0,    0,    0,    0,    0,  104,   93,    0,  134,    0,
    0,  116,    0,    0,  362,  367,  354,  356,    0,  358,
  363,  360,    0,    0,  421,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  174,    0,    0,    0,  190,    0,
  214,  212,  210,  213,    0,    0,  274,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  247,    0,    0,    0,    0,    0,  223,  224,
  225,  241,  239,    0,   28,    0,    0,    0,    0,  407,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  422,  388,  394,  395,  396,  397,  393,  398,  389,
  386,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  233,  232,  230,
    0,  217,  226,  259,  266,  267,  268,  263,  264,  262,
  265,  271,  269,  270,  272,  261,  260,    0,    0,    0,
    0,    0,    0,    0,   27,    0,    0,    0,  406,    0,
  159,  154,  142,  143,  144,  152,  158,  146,  145,  147,
  155,  141,  150,  148,  149,  153,  160,  156,  151,  157,
   63,   62,   66,   87,   84,   85,   86,  110,  111,   41,
   39,   40,   42,    0,    0,    0,    0,    0,    0,    0,
  334,  342,    0,    0,   96,   97,   98,   99,   44,   45,
  137,  120,  121,  122,  119,    0,  369,  370,  371,  366,
  186,  278,  280,  279,  284,  285,  277,  286,  276,  287,
  283,  177,  184,  178,  179,  180,  181,  182,  183,  281,
  282,  185,  193,  194,  195,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  410,  411,
  409,  404,    0,    0,    0,    0,    0,    0,    0,  108,
  332,  124,  235,    0,    0,  243,  244,  245,  242,    0,
  219,  220,  221,  222,  246,    0,    0,    0,    0,    0,
    0,    0,    0,  227,  248,  335,  336,  337,  338,  339,
  340,  341,  234,
};
const short yydgoto[] = {                                       9,
   14,   16,   18,   28,   20,   23,   25,   26,  102,  103,
  104,  105,  318,  320,  106,  324,  322,  442,  440,  107,
  450,  563,  108,  330,  847,  109,  332,  138,  139,  140,
  357,  141,  359,  142,  363,  361,  489,  487,  143,  374,
  144,  145,  370,  146,  372,  900,   40,   41,  153,  154,
  257,  518,   83,   84,  121,  122,  340,  341,  343,  344,
  125,  760,  202,  203,  204,  879,  278,  279,  298,  299,
  754,  755,   10,   11,   85,  311,  312,  578,  579,  546,
  433,  547,  580,  551,  435,  552,  211,  210,  213,  212,
  566,  439,  437,  567,  585,  443,  586,  581,  582,  441,
  583,  729,  993,  216,  601,  451,  602,  741,  449,  593,
  447,  594,  648,  480,  649,  820,  655,  482,  656,  241,
  240,  243,  242,  657,  486,  484,  793,  821,  796,  662,
  922,  822,  795,  660,  920, 1037,  682,  516,  823,  939,
  666,  495,  513,  373,  514,  994,  605,  454,  461,  611,
  462,  463,  452,  612,  606,  472,  354,  477,  355,  478,
  473,  474,  475,  691,  693,  523,  692,
};
const short yysindex[] = {                                   -188,
 -318, -318, -318, -318,  -67,  -61, -318, -318,    0,    0,
    7,    0,    0,    0,  -29,    0,  -10,    0,   -8,    0,
    9, -154,    0,  133,    0,    0,    0,    0,   10, -188,
 -182,  -25, -271,  591,   81,   90,   95,   96,   97, -123,
   82,  100,  103,  112,  114,  115,  117,  125,  127,  129,
  134,  150,  152,  154,  162,  163,  164,  169,  175,  176,
  177,  188,  189,  190,  191,  200,  207,  209,  211,  215,
  216,  217,  218,  222,  223,  224,  225,  226,  227,  228,
  230,  231,  147,  214,  161, -282,    0,  245,  250,  255,
  256,  257,    0,    0,    0,    0,  258,  259,    0,    0,
    0,  178,  241,    0,    0,    0,    0,    0,    0,  261,
  262,  264,  270,  271,  274,  275,  282,  283,  -25,  -25,
  -54,    0,  284,  285,  267,  287,  288,  289,  290,    0,
    0,    0,    0,  291,  292,  293,  294,  212,  277,    0,
    0,    0,    0,    0,    0,    0, -318, -318, -318, -318,
 -318,  219,    4, -123, -154,  -55,  -50,  -43,  -42,  -41,
  -38, -318, -318, -321, -321, -321, -321,  -34, -321, -265,
 -321, -321,  -36,  -28,  -27, -318, -318,  -26,  -23,  -17,
  -15, -318, -318,  -13,  -12,  -11, -321, -336, -336,   -9,
 -336, -336,   -7, -321,   -4,   -3,    0,  133, -242,  331,
  337, -282,  263,    0,  339, -318, -318, -318, -318,  346,
  354,  355,  356, -318, -318,  357,    0, -182, -318, -318,
 -318, -299, -318, -318, -318, -318, -318,    0,  -37,  -25,
  -25,  276,    0,    0,  278, -318, -318, -318, -318,  360,
  362,  364,  365, -318, -318,    0, -318,    0,  591,  367,
  368,  369,  370,  371, -154,  373,  281,    0,    0,  374,
  375,  376,  377,  378,  379,  380,  381,    0,    0,    0,
  382,  383,  407,  408,  412,  415,    0,    0,  416,  417,
  419,  420,  421,  423,  424,  425,  426,  435,  436,  444,
  445,  446,  447,  451,  452,  453,    0,    0,  454,  455,
  456,  459,  460,  461,  462,  464,  465,    0,  468,  470,
  386,  348, -318, -318,    0,    0,    0,  471,    0,  472,
    0,  473,    0,  474,    0,    0,    0,    0,    0,  475,
    0,  476,    0,    0,    0,    0,  480,    0,  481,  482,
 -318,    0,  486, -318,   20,    0,    0,    0,  488,    0,
  132,    0,    0, -164,  295,    0,  507,    0,  510,    0,
  511,    0,  512,    0, -318, -318, -318, -318,  513,  514,
    0,  519,   -2,  520,    0,    0,    0,    0,    0,    0,
    0, -123, -318,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, -318, -321,    0, -242,    0,
 -318,    0,  -16,    0,  938,    0,  661,    0,  661,  521,
  584,  523,  738,  525,  526,    0, -234,    0,  981,  527,
  485, -223,    0, -223,    0,    0,    0,    0,    0, -318,
 -223, -245, -223,    0,  530,  532,  533,  540,  541,  542,
  543,  544,    0,    0, -164,  547,  549,  295,    0,  578,
    0,  260,    0,    0,    0,    0,  550,    0,  551,    0,
  552,  553,    0,    0,  363,    0,  556,  558,  559,  560,
  561,  562,  563,  564,  565,  569,  570,  585,  586,  587,
    0,    0,    0,   -2,    0,    0,    4,  583, -318,  588,
  590,    0, -240,    0,  594,  597,  598,  599,  600,  601,
  604,  605,  606,  607,  608,  609,  610,  611,  612,  613,
  614,  615,  616,  617,  618,    0,  -16,    0,  625,  981,
    0,    0,  634,  635,  636,  638,  646,  647,  648,  650,
  651,  654,    0,    0,    0,    0,  661,    0,    0,    0,
  655,  656,  657,  659,  662,  664,    0,    0,    0,    0,
    0,    0,  584,    0,    0,  738,    0,    0,    0,  669,
    0,    0,    0, -234,    0,    0,  671,    0,    0,    0,
    0,  485,  674,  677,  679, -223,  680,    0,  682,  684,
  685, -245,    0,  686, -318, -318, -318, -318, -318, -318,
 -318,    0,    0, -318,    0,    0,  688,  692,  696,  698,
  700,  701,  704,  705,  706,  707,  709,  710,  711,  713,
  714,  715,  716,  717,  718,  719,  721,    0,  578,    0,
  722,  723,  725,    0,    0,  260,  366,  366,    0,    0,
    0,    0,    0,    0,  363,    0, -318, -318, -318, -318,
 -318, -318, -318, -318,  130,  232,  329, -318, -336, -318,
    0,  172,  641,  720,    0,    0,    0,  728,  729,  733,
  734, -240, -240, -318,  384, -321, -321, -321, -321, -321,
 -265, -321, -321,  387,  389, -318, -318, -318, -318,  390,
 -318,  400, -318, -318,    0, -321,    0, -321, -336, -336,
  404, -321,  405, -321,  406,  409, -321,    0,  737, -318,
 -318, -336, -336,  418,  422,    0,    0, -318,    0, -225,
  742,    0, -318, -318,    0,    0,    0,    0, -318,    0,
    0,    0, -318,  762,    0,  763,  770,  772,  774,  775,
 -318,  776,  778, -321,  427,  428,  432, -318,  433,  434,
  437, -318, -318, -321, -321, -336, -336,  438, -336, -336,
  439, -318, -321,  440,    0, -336, -336,  441,    0,  792,
    0,    0,    0,    0,  866,  791,    0,  790,  797,  799,
  807,  823,  824,  827,  830,  831,  832,  836,  837,  839,
  841,  844,    0,  850,  858,  859,  861,  862,    0,    0,
    0,    0,    0,  851,    0, -318, -318, -318,  853,    0,
  873,  875,  876,  877,  891,  893,  894,  895,  906,  913,
  914,  915,  916,  917,  918,  920,  921, -318,  926,  931,
  932,  933,  934,  935,  936,  937,  939,  940,  946,  947,
  948,  949,  950,  951, -133,  952,  953,  954,  958,  959,
  960,  961,  962,  963,  965,  969, -133,  970,  971, -318,
  972,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  973,  975,  978,  979,  980,  983,  984,  986,  990,
 -318,  991,  992,  993,  994,  995,  997,  998, 1003, 1008,
 1009, 1010, 1023, 1024, 1025, 1026, -321,    0,    0,    0,
  863,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, -211,  982, -318,
 -336, -336, -336, -321,    0, 1027, 1028, 1029,    0, 1012,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1032, 1036, 1037, 1038, 1039, 1040, 1041,
    0,    0, 1042, -133,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1043,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1044, 1046, -321, 1049, 1050,
 1052, 1053, -133, 1054, 1059, 1060, 1070, 1071,    0,    0,
    0,    0, -318, -318, -318, -318, -318, -318, -318,    0,
    0,    0,    0, -133, 1072,    0,    0,    0,    0, 1073,
    0,    0,    0,    0,    0, 1074, 1075, 1077, 1078, 1079,
 1080, 1081, 1082,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,
};
const short yyrindex[] = {                                   1124,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, -101,    0,  649,    0,    0,    0,    0,    0, 1124,
  653,    0,    0,  854,    0,    0,    0,    0,    0,  -96,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  957,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1000,  -96, -101,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  649, 1002,    0,
    0,  957,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  653,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  854,    0,
    0,    0,    0,    0, -101,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1088,    0,    0,  367,  -19,    0,    0,    0,    0,    0,
  -24,    0,    0,  380,  374,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1089,    0,    0,    0,    0,    0,    0,    0,
    0,  -96, 1090,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1002,    0,
    0,    0, 1091,    0, 1092,    0, 1093,    0, 1093,    0,
 1094,    0, 1095,    0,    0,    0, 1096,    0, 1092,    0,
 1097, 1098,    0, 1098,    0,    0,    0,    0,    0,    0,
 1098, 1099, 1098,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  380,    0,    0,  374,    0, 1100,
    0, 1101,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1104,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1089,    0,    0, 1000,    0, 1090,    0,
    0,    0,  435,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1091,    0,    0, 1092,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1093,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1094,    0,    0, 1095,    0,    0,    0,    0,
    0,    0,    0, 1096,    0,    0,    0,    0,    0,    0,
    0, 1097,    0,    0,    0, 1098,    0,    0,    0,    0,
    0, 1099,    0,    0,  462,    0,    0,    0,    0,  416,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1100,    0,
    0,    0,    0,    0,    0, 1101, 1105, 1107,    0,    0,
    0,    0,    0,    0, 1104,    0,    0,  462,  462,  462,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1109,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  435,  435,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1113,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1125,    0,    0,    0,    0,    0,    0,
    0,    0,  462,    0,    0,    0,    0,    0,    0,    0,
  416,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1126,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1127, 1128,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1125,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1113,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1129,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1129,    0,    0, 1125,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1126,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1129,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1129,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  462,  462,    0,
    0,    0,    0, 1129,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,
};
const short yygindex[] = {                                      0,
    0,    0,    0,    0,    0,    0,    0,    0,  955,    0,
    0,    0,    0,    0,    0,    0,    0,  842,  846,    0,
    0, -415,    0,    0, -264,    0,    0,  923,    0,    0,
    0,    0,    0,    0,    0,    0,  808,  798,    0,    0,
    0,    0,    0,    0,    0,  279,  -75,    0, -134,    0,
  658,  660,  988,    0,  -52,    0,  840,    0,  833,    0,
    0,  429,    0,    0,  976, -781, -153,  487,   -1, -144,
 -660,  442, 1152,    0,    0,  758,    0, -416, -651,  642,
    0,    0, -384,    0,    0, -397,    0,    0,    0,    0,
 -411,    0,    0,    0,  619,    0,    0, -413,  621,    0,
    0,    0, -852,    0,  589,    0,    0,    0,    0,  602,
    0,    0,  545,    0,    0, -404,  546,    0,    0,    0,
    0,    0,    0,  712,    0,    0,    0, -540,    0,    0,
    0, -669,    0,    0,    0,    0,    0,    0,    0,    0,
  534,    0,  683,    0,    0,    0, -421,    0,    0,  595,
    0,    0,    0,    0, -435,  731,    0,  730,    0,    0,
    0,    0,    0, -564,    0,    0,    0,
};
#define YYTABLESIZE 1335
const short yytable[] = {                                      15,
   17,   19,   21,  350,  232,   27,   29,  799,  800,  801,
  271,  272,  273,  274,  120,  276,  345,  280,  281,  258,
  564,  379,  564,   19, 1006,  577,  613,  568,   26,  587,
  819,  603,  607,  296,  345,  599,  688,  600,  590,  609,
  305,  614,  873,  874,  300,  947,  302,  303,  548,  277,
  550,  595,  565,  603,  565,   22, 1039, 1040,   12,  297,
   13,   24,  268,  269,  550,   30,  228,  229,    1,    2,
    3,    4,    5,    6,  270,  650,   12,  654,   13,  259,
   88,   89,   90,   91,   92,   93,   94,   95,   96,  604,
  665,   97,   98,   31,  689,   12,  339,   13, 1009,  200,
  201,  875,   35,   36,   37,   38,  123,   99,  124,  309,
  310,  604,   32,  465,   33, 1041,  794,  794,  268,  269,
  147,  466,  467,  468,  469,  919,  923,  830,  831,  148,
  270,   34,   86,  610,  149,  150,  151,  152,  690,  156,
  155, 1061,  157,  819,  819,  250,  251,  252,  253,  254,
  564,  158,  717,  159,  160,  728,  161,  591,  592,   19,
  266,  267,  548,    7,  162,  550,  163,  577,  164,   12,
  470,   13,  587,  165,  285,  286,  613,  351,  352,  382,
  291,  292,  565,   12,  746,   13,  599,  471,  600,  166,
 1070,  167,    8,  168,  984,  985,  986,  987,  988,  989,
  990,  169,  170,  171,  319,  321,  323,  325,  172,  100,
  101, 1083,  331,  333,  173,  174,  175,  336,  337,  338,
  342,  345,  346,  347,  348,  349,   39,  176,  177,  178,
  179,  110,  111,   19,  358,  360,  362,  364,   26,  180,
  791,  791,  369,  371,  650,  375,  181,  517,  182,  112,
  183,  654,  792,  792,  184,  185,  186,  187,  991,  992,
  665,  188,  189,  190,  191,  192,  193,  194,  525,  195,
  196,  197,  198,  521,  497,  498,  499,  500,  501,  502,
  503,  504,  526,  199,  205,  527,  528,  529,  530,  206,
  531,  532,  533,  534,  207,  208,  209,  214,  215,  218,
  219,  220,  217,  221,  535,  536,  537,  538,  539,  222,
  223,  430,  431,  224,  225,  505,  506,  507,  540,  541,
  542,  226,  227,  233,  234,  235,  236,  237,  238,  239,
  244,  245,  246,  247,  508,  249,  248,  543,  256,  342,
  260,  255,  345,  230,  231,  261,  113,  114,  115,  116,
  117,  118,  262,  263,  264,  544,  545,  265,  509,  282,
  230,  231,  275,  488,  490,  488,  490,  283,  284,  287,
  313,  510,  288,  345,  119,  379,  314,  379,  289,  317,
  290,  519,  293,  294,  295,  326,  301,  316,  304,  511,
  512,  306,  307,  327,  328,  329,  334, 1081, 1082,  365,
  353,  366,  356,  367,  368,  384,  429,  377,  378,  379,
  380,  381,  383,  460,  385,  386,  387,  388,  389,  390,
  391,  392,  393,  394,  520,   42,   43,   44,   45,  524,
   46,   47,   48,   49,   50,   51,   52,   53,   54,   55,
   56,   57,   58,   59,   60,   61,   62,  395,  396,   63,
   64,   65,  397,   66,   67,  398,  399,  400,  608,  401,
  402,  403,  812,  404,  405,  406,  407,  628,  629,  630,
   68,   69,   70,   71,   72,  408,  409,   73,   74,   75,
   76,   77,   78,   79,  410,  411,  412,  413,  631,  632,
  633,  414,  415,  416,  417,  418,  419,  634,  813,  420,
  421,  422,  423,   80,  424,  425,  635,  426,  636,  427,
  428,  432,  434,  436,  438,  446,  448,  519,   81,   82,
  453,  455,  456,  645,  646,  806,  458,  790,  464,  814,
  231,  815,  816,  817,  810,  575,  559,  576,  560,  561,
  562,  818,  834,  835,  836,  837,  838,  479,  840,  841,
  481,  483,  485,  493,  494,  628,  629,  630,  476,  496,
  515,  569,  854,  584,  855,  588,  589,  596,  859,  615,
  861,  616,  617,  864,  856,  857,  631,  632,  633,  618,
  619,  620,  621,  967,  622,  634,  624,  868,  869,  625,
  659,  661,  663,  664,  635,  667,  636,  668,  669,  670,
  671,  672,  673,  674,  675,  651,  652,  653,  676,  677,
  892,  645,  646,  753,  756,  757,  758,  759,  761,  762,
  903,  904,  763,  684,  678,  679,  680,  807,  686,  912,
  687,  905,  906,  694,  908,  909,  695,  696,  697,  698,
  699,  914,  915,  700,  701,  702,  703,  704,  705,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  628,  629,
  630,  628,  629,  630,  716,  798,  753,  753,  753,  802,
  803,  804,  805,  718,  719,  720,  809,  721,  811,  631,
  632,  633,  631,  632,  633,  722,  723,  724,  634,  725,
  726,  634,  832,  727,  730,  731,  732,  635,  733,  636,
  635,  734,  636,  735,  844,  845,  846,  848,  738,  850,
  740,  852,  853,  743,  645,  646,  744,  645,  646,  745,
  747,  790,  748,  749,  808,  750,  752,  764,  866,  867,
  559,  765,  560,  561,  562,  766,  872,  767,  876,  768,
  769,  878,  880,  770,  771,  772,  773,  881,  774,  775,
  776,  753,  777,  778,  779,  780,  781,  782,  783,  761,
  784,  786,  787, 1036,  788,  824,  896,  826,  827,  525,
  901,  902,  828,  290,  829,  597,  865,   47,  825,  833,
  911,  877,  842,  526,  843,  849,  527,  528,  529,  530,
 1048,  531,  532,  533,  534,  851, 1045, 1046, 1047,  858,
  860,  862,  883,  884,  863,  535,  536,  537,  538,  539,
  885,  598,  886,  870,  887,  888,  890,  871,  891,  540,
  541,  542,  893,  894,  946,  880,  948,  895,  897,  898,
  924,  917,  899,  907,  910,  913,  916,  925,  543,  926,
  557,  558,  571,  572,  573,  574,  848,  927,  575,  559,
  576,  560,  561,  562,  126,  127,  128,  129,  130,  131,
  132,  133,  134,  928,  929,  135,  136,  930,  525,  627,
  931,  932,  933,  628,  629,  630,  934,  935,  880,  936,
  137,  937,  526,  938, 1065,  527,  528,  529,  530,  940,
  531,  532,  533,  534,  631,  632,  633,  941,  942,  901,
  943,  944, 1038,  634,  535,  536,  537,  538,  539,  945,
  570,  949,  635,  950,  636,  951,  952,  953,  540,  541,
  542,  637,  638,  639,  640,  641,  642,  643,  644,  645,
  646,  954,  647,  955,  956,  957, 1042,  543, 1044,  557,
  558,  571,  572,  573,  574,  525,  958,  575,  559,  576,
  560,  561,  562,  959,  960,  961,  962,  963,  964,  526,
  965,  966,  527,  528,  529,  530,  968,  531,  532,  533,
  534,  969,  970,  971,  972,  973,  974,  975,  163,  976,
  977,  535,  536,  537,  538,  539,  978,  979,  980,  981,
  982,  983,  995,  996,  997,  540,  541,  542,  998,  999,
 1000, 1001, 1002, 1003,  553, 1004,  554,  555,  556, 1005,
 1007, 1008, 1010, 1011,  543, 1012,  557,  558, 1013, 1014,
 1015, 1043,  525, 1016, 1017,  559, 1018,  560,  561,  562,
 1019, 1021, 1022, 1023, 1024, 1025,  526, 1026, 1027,  527,
  528,  529,  530, 1028,  531,  532,  533,  534, 1029, 1030,
 1031, 1076, 1077, 1078, 1079, 1080,  753,  753,  535,  536,
  537,  538,  539, 1032, 1033, 1034, 1035, 1049, 1050, 1051,
 1052, 1053,  540,  541,  542, 1054, 1055, 1056, 1057, 1058,
 1059,  402, 1060, 1062, 1063, 1064,  628,  629,  630, 1066,
 1067,  543, 1068, 1069, 1071,  571,  572,  573,  574, 1072,
 1073,  575,  559,  576,  560,  561,  562,  631,  632,  633,
 1074, 1075, 1084, 1085, 1086, 1087,  634, 1088, 1089, 1090,
 1091, 1092, 1093,    3,   29,  635,   36,  636,  374,  257,
   31,   60,  140,   83,  105,   94,  135,  117,  368,  364,
  175,  191,  645,  646,  275,  209,  790,  207,  814,  238,
  815,  816,  817,  161,  575,  559,  576,  560,  561,  562,
  921,  628,  629,  630,  491,  372,  288,  229,  216,  333,
  445,  376,  335,  444,  683,  492,  459,  315,  685, 1020,
  457,   87,  631,  632,  633,  308,  522,  839,  715,  889,
  742,  634,  918,  785,  882,  739,  681,  658,  797,    0,
  635,  789,  636,  736,  737,  623,  751,  626,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  645,  646,    0,
    0,  790,  525,  814,    0,  815,  816,  817,    0,  575,
  559,  576,  560,  561,  562,    0,  526,    0,    0,  527,
  528,  529,  530,    0,  531,  532,  533,  534,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  535,  536,
  537,  538,  539,    0,    0,  525,    0,    0,    0,    0,
    0,    0,  540,  541,  542,    0,    0,    0,    0,  526,
    0,  549,  527,  528,  529,  530,    0,  531,  532,  533,
  534,  543,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  535,  536,  537,  538,  539,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  540,  541,  542,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  543,
};
const short yycheck[] = {                                       1,
    2,    3,    4,   41,   59,    7,    8,  668,  669,  670,
  164,  165,  166,  167,   40,  169,   41,  171,  172,  154,
  437,   41,  439,  125,  877,  441,  462,  439,  125,  443,
  682,  277,  454,  187,   59,  451,  277,  451,  273,  461,
  194,  463,  268,  269,  189,  827,  191,  192,  433,  315,
  435,  449,  437,  277,  439,  123,  268,  269,  395,  396,
  397,  123,  384,  385,  449,   59,  119,  120,  257,  258,
  259,  260,  261,  262,  396,  480,  395,  482,  397,  155,
  263,  264,  265,  266,  267,  268,  269,  270,  271,  335,
  495,  274,  275,  123,  335,  395,  396,  397,  880,  382,
  383,  327,  257,  258,  259,  260,  378,  290,  380,  352,
  353,  335,  123,  278,  123,  327,  657,  658,  384,  385,
   40,  286,  287,  288,  289,  795,  796,  692,  693,   40,
  396,  123,  123,  379,   40,   40,   40,  261,  379,   40,
   59,  994,   40,  795,  796,  147,  148,  149,  150,  151,
  567,   40,  550,   40,   40,  567,   40,  392,  393,  261,
  162,  163,  547,  352,   40,  550,   40,  583,   40,  395,
  335,  397,  586,   40,  176,  177,  612,  230,  231,  255,
  182,  183,  567,  395,  606,  397,  602,  352,  602,   40,
 1043,   40,  381,   40,  328,  329,  330,  331,  332,  333,
  334,   40,   40,   40,  206,  207,  208,  209,   40,  392,
  393, 1064,  214,  215,   40,   40,   40,  219,  220,  221,
  222,  223,  224,  225,  226,  227,  381,   40,   40,   40,
   40,  257,  258,  335,  236,  237,  238,  239,  335,   40,
  657,  658,  244,  245,  649,  247,   40,  382,   40,  275,
   40,  656,  657,  658,   40,   40,   40,   40,  392,  393,
  665,   40,   40,   40,   40,   40,   40,   40,  285,   40,
   40,  125,   59,  427,  277,  278,  279,  280,  281,  282,
  283,  284,  299,  123,   40,  302,  303,  304,  305,   40,
  307,  308,  309,  310,   40,   40,   40,   40,   40,   59,
   40,   40,  125,   40,  321,  322,  323,  324,  325,   40,
   40,  313,  314,   40,   40,  318,  319,  320,  335,  336,
  337,   40,   40,   40,   40,   59,   40,   40,   40,   40,
   40,   40,   40,   40,  337,   59,  125,  354,  335,  341,
  396,  123,  344,  398,  399,  396,  372,  373,  374,  375,
  376,  377,  396,  396,  396,  372,  373,  396,  361,  396,
  398,  399,  397,  365,  366,  367,  368,  396,  396,  396,
   40,  374,  396,  398,  400,  395,   40,  397,  396,   41,
  396,  383,  396,  396,  396,   40,  396,  125,  396,  392,
  393,  396,  396,   40,   40,   40,   40, 1058, 1059,   40,
  125,   40,  125,   40,   40,  125,   59,   41,   41,   41,
   41,   41,   40,  394,   41,   41,   41,   41,   41,   41,
   41,   41,   41,   41,  426,  293,  294,  295,  296,  431,
  298,  299,  300,  301,  302,  303,  304,  305,  306,  307,
  308,  309,  310,  311,  312,  313,  314,   41,   41,  317,
  318,  319,   41,  321,  322,   41,   41,   41,  460,   41,
   41,   41,  291,   41,   41,   41,   41,  296,  297,  298,
  338,  339,  340,  341,  342,   41,   41,  345,  346,  347,
  348,  349,  350,  351,   41,   41,   41,   41,  317,  318,
  319,   41,   41,   41,   41,   41,   41,  326,  327,   41,
   41,   41,   41,  371,   41,   41,  335,   40,  337,   40,
  125,   41,   41,   41,   41,   41,   41,  519,  386,  387,
   41,   41,   41,  352,  353,  396,   41,  356,   41,  358,
  399,  360,  361,  362,  679,  364,  365,  366,  367,  368,
  369,  370,  696,  697,  698,  699,  700,   41,  702,  703,
   41,   41,   41,   41,   41,  296,  297,  298,  264,   41,
   41,   41,  716,   41,  718,   41,   41,   41,  722,   40,
  724,   40,   40,  727,  719,  720,  317,  318,  319,   40,
   40,   40,   40,  848,   41,  326,   40,  732,  733,   41,
   41,   41,   41,   41,  335,   40,  337,   40,   40,   40,
   40,   40,   40,   40,   40,  346,  347,  348,   40,   40,
  764,  352,  353,  615,  616,  617,  618,  619,  620,  621,
  774,  775,  624,   41,   40,   40,   40,  396,   41,  783,
   41,  776,  777,   40,  779,  780,   40,   40,   40,   40,
   40,  786,  787,   40,   40,   40,   40,   40,   40,   40,
   40,   40,   40,   40,   40,   40,   40,   40,  296,  297,
  298,  296,  297,  298,   40,  667,  668,  669,  670,  671,
  672,  673,  674,   40,   40,   40,  678,   40,  680,  317,
  318,  319,  317,  318,  319,   40,   40,   40,  326,   40,
   40,  326,  694,   40,   40,   40,   40,  335,   40,  337,
  335,   40,  337,   40,  706,  707,  708,  709,   40,  711,
   40,  713,  714,   40,  352,  353,   40,  352,  353,   41,
   41,  356,   41,   40,  396,   41,   41,   40,  730,  731,
  365,   40,  367,  368,  369,   40,  738,   40,  740,   40,
   40,  743,  744,   40,   40,   40,   40,  749,   40,   40,
   40,  753,   40,   40,   40,   40,   40,   40,   40,  761,
   40,   40,   40,  917,   40,  125,  768,   40,   40,  285,
  772,  773,   40,  125,   41,  291,   40,  125,   59,  396,
  782,   40,  396,  299,  396,  396,  302,  303,  304,  305,
  944,  307,  308,  309,  310,  396,  941,  942,  943,  396,
  396,  396,   41,   41,  396,  321,  322,  323,  324,  325,
   41,  327,   41,  396,   41,   41,   41,  396,   41,  335,
  336,  337,  396,  396,  826,  827,  828,  396,  396,  396,
   41,   40,  396,  396,  396,  396,  396,   41,  354,   41,
  356,  357,  358,  359,  360,  361,  848,   41,  364,  365,
  366,  367,  368,  369,  264,  265,  266,  267,  268,  269,
  270,  271,  272,   41,   41,  275,  276,   41,  285,  292,
   41,   41,   41,  296,  297,  298,   41,   41,  880,   41,
  290,   41,  299,   40, 1038,  302,  303,  304,  305,   40,
  307,  308,  309,  310,  317,  318,  319,   40,   40,  901,
   40,   40,   40,  326,  321,  322,  323,  324,  325,   59,
  327,   59,  335,   41,  337,   41,   41,   41,  335,  336,
  337,  344,  345,  346,  347,  348,  349,  350,  351,  352,
  353,   41,  355,   41,   41,   41,  938,  354,  940,  356,
  357,  358,  359,  360,  361,  285,   41,  364,  365,  366,
  367,  368,  369,   41,   41,   41,   41,   41,   41,  299,
   41,   41,  302,  303,  304,  305,   41,  307,  308,  309,
  310,   41,   41,   41,   41,   41,   41,   41,  125,   41,
   41,  321,  322,  323,  324,  325,   41,   41,   41,   41,
   41,   41,   41,   41,   41,  335,  336,  337,   41,   41,
   41,   41,   41,   41,  344,   41,  346,  347,  348,   41,
   41,   41,   41,   41,  354,   41,  356,  357,   41,   41,
   41,   40,  285,   41,   41,  365,   41,  367,  368,  369,
   41,   41,   41,   41,   41,   41,  299,   41,   41,  302,
  303,  304,  305,   41,  307,  308,  309,  310,   41,   41,
   41, 1053, 1054, 1055, 1056, 1057, 1058, 1059,  321,  322,
  323,  324,  325,   41,   41,   41,   41,   41,   41,   41,
   59,   40,  335,  336,  337,   40,   40,   40,   40,   40,
   40,  125,   41,   41,   41,   40,  296,  297,  298,   41,
   41,  354,   41,   41,   41,  358,  359,  360,  361,   41,
   41,  364,  365,  366,  367,  368,  369,  317,  318,  319,
   41,   41,   41,   41,   41,   41,  326,   41,   41,   41,
   41,   41,   41,    0,  125,  335,  125,  337,   41,   41,
   41,   41,   41,   41,   41,   41,   41,   41,   41,   41,
   41,   41,  352,  353,   41,   41,  356,   41,  358,   41,
  360,  361,  362,   41,  364,  365,  366,  367,  368,  369,
  370,  296,  297,  298,  367,   41,   41,   41,   41,   41,
  329,  249,  218,  328,  517,  368,  344,  202,  519,  901,
  341,   30,  317,  318,  319,  198,  429,  701,  547,  761,
  602,  326,  327,  649,  753,  594,  514,  486,  665,   -1,
  335,  656,  337,  583,  586,  475,  612,  478,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  352,  353,   -1,
   -1,  356,  285,  358,   -1,  360,  361,  362,   -1,  364,
  365,  366,  367,  368,  369,   -1,  299,   -1,   -1,  302,
  303,  304,  305,   -1,  307,  308,  309,  310,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  321,  322,
  323,  324,  325,   -1,   -1,  285,   -1,   -1,   -1,   -1,
   -1,   -1,  335,  336,  337,   -1,   -1,   -1,   -1,  299,
   -1,  344,  302,  303,  304,  305,   -1,  307,  308,  309,
  310,  354,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  321,  322,  323,  324,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  335,  336,  337,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  354,
};
#define YYFINAL 9
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
#define YYMAXTOKEN 400
#if YYDEBUG
const char * const yyname[] = {
"end-of-file",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,"'('","')'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"';'",0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'{'",0,"'}'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"KW_SOURCE",
"KW_FILTER","KW_PARSER","KW_DESTINATION","KW_LOG","KW_OPTIONS","KW_INTERNAL",
"KW_FILE","KW_PIPE","KW_UNIX_STREAM","KW_UNIX_DGRAM","KW_TCP","KW_UDP",
"KW_TCP6","KW_UDP6","KW_USERTTY","KW_DOOR","KW_SUN_STREAMS","KW_PROGRAM",
"KW_SQL","KW_TYPE","KW_COLUMNS","KW_INDEXES","KW_VALUES","KW_PASSWORD",
"KW_DATABASE","KW_USERNAME","KW_TABLE","KW_ENCODING","KW_DELIMITERS",
"KW_QUOTES","KW_QUOTE_PAIRS","KW_NULL","KW_SYSLOG","KW_TRANSPORT","KW_FSYNC",
"KW_MARK_FREQ","KW_STATS_FREQ","KW_STATS_LEVEL","KW_FLUSH_LINES","KW_SUPPRESS",
"KW_FLUSH_TIMEOUT","KW_LOG_MSG_SIZE","KW_FILE_TEMPLATE","KW_PROTO_TEMPLATE",
"KW_CHAIN_HOSTNAMES","KW_NORMALIZE_HOSTNAMES","KW_KEEP_HOSTNAME",
"KW_CHECK_HOSTNAME","KW_BAD_HOSTNAME","KW_KEEP_TIMESTAMP","KW_USE_DNS",
"KW_USE_FQDN","KW_DNS_CACHE","KW_DNS_CACHE_SIZE","KW_DNS_CACHE_EXPIRE",
"KW_DNS_CACHE_EXPIRE_FAILED","KW_DNS_CACHE_HOSTS","KW_PERSIST_ONLY",
"KW_TZ_CONVERT","KW_TS_FORMAT","KW_FRAC_DIGITS","KW_LOG_FIFO_SIZE",
"KW_LOG_DISK_FIFO_SIZE","KW_LOG_FETCH_LIMIT","KW_LOG_IW_SIZE","KW_LOG_PREFIX",
"KW_PROGRAM_OVERRIDE","KW_HOST_OVERRIDE","KW_THROTTLE","KW_TLS",
"KW_PEER_VERIFY","KW_KEY_FILE","KW_CERT_FILE","KW_CA_DIR","KW_CRL_DIR",
"KW_TRUSTED_KEYS","KW_TRUSTED_DN","KW_FLAGS","KW_PAD_SIZE","KW_TIME_ZONE",
"KW_RECV_TIME_ZONE","KW_SEND_TIME_ZONE","KW_TIME_REOPEN","KW_TIME_REAP",
"KW_TIME_SLEEP","KW_TMPL_ESCAPE","KW_OPTIONAL","KW_CREATE_DIRS","KW_OWNER",
"KW_GROUP","KW_PERM","KW_DIR_OWNER","KW_DIR_GROUP","KW_DIR_PERM","KW_TEMPLATE",
"KW_TEMPLATE_ESCAPE","KW_FOLLOW_FREQ","KW_OVERWRITE_IF_OLDER","KW_KEEP_ALIVE",
"KW_MAX_CONNECTIONS","KW_LOCALIP","KW_IP","KW_LOCALPORT","KW_PORT",
"KW_DESTPORT","KW_FRAMED","KW_IP_TTL","KW_SO_BROADCAST","KW_IP_TOS",
"KW_SO_SNDBUF","KW_SO_RCVBUF","KW_SO_KEEPALIVE","KW_SPOOF_SOURCE",
"KW_USE_TIME_RECVD","KW_FACILITY","KW_LEVEL","KW_HOST","KW_MATCH","KW_MESSAGE",
"KW_NETMASK","KW_CSV_PARSER","KW_VALUE","KW_DB_PARSER","KW_REWRITE","KW_SET",
"KW_SUBST","KW_YES","KW_NO","KW_GC_IDLE_THRESHOLD","KW_GC_BUSY_THRESHOLD",
"KW_COMPRESS","KW_MAC","KW_AUTH","KW_ENCRYPT","KW_IFDEF","KW_ENDIF","DOTDOT",
"IDENTIFIER","NUMBER","STRING","KW_OR","KW_AND","KW_NOT",
};
const char * const yyrule[] = {
"$accept : start",
"start : stmts",
"stmts : stmt ';' stmts",
"stmts :",
"stmt : KW_SOURCE source_stmt",
"stmt : KW_DESTINATION dest_stmt",
"stmt : KW_LOG log_stmt",
"stmt : KW_FILTER filter_stmt",
"stmt : KW_PARSER parser_stmt",
"stmt : KW_REWRITE rewrite_stmt",
"stmt : KW_TEMPLATE template_stmt",
"stmt : KW_OPTIONS options_stmt",
"source_stmt : string '{' source_items '}'",
"filter_stmt : string '{' filter_expr ';' '}'",
"parser_stmt : string '{' parser_expr ';' '}'",
"rewrite_stmt : string '{' rewrite_expr_list '}'",
"dest_stmt : string '{' dest_items '}'",
"log_stmt : '{' log_items log_forks log_flags '}'",
"log_items : log_item ';' log_items",
"log_items :",
"log_item : KW_SOURCE '(' string ')'",
"log_item : KW_FILTER '(' string ')'",
"log_item : KW_PARSER '(' string ')'",
"log_item : KW_REWRITE '(' string ')'",
"log_item : KW_DESTINATION '(' string ')'",
"log_forks : log_fork log_forks",
"log_forks :",
"log_fork : KW_LOG '{' log_items log_forks log_flags '}' ';'",
"log_flags : KW_FLAGS '(' log_flags_items ')' ';'",
"log_flags :",
"log_flags_items : string log_flags_items",
"log_flags_items :",
"options_stmt : '{' options_items '}'",
"$$1 :",
"template_stmt : string $$1 '{' template_items '}'",
"template_items : template_item ';' template_items",
"template_items :",
"template_item : KW_TEMPLATE '(' string ')'",
"template_item : KW_TEMPLATE_ESCAPE '(' yesno ')'",
"socket_option : KW_SO_SNDBUF '(' NUMBER ')'",
"socket_option : KW_SO_RCVBUF '(' NUMBER ')'",
"socket_option : KW_SO_BROADCAST '(' yesno ')'",
"socket_option : KW_SO_KEEPALIVE '(' yesno ')'",
"inet_socket_option : socket_option",
"inet_socket_option : KW_IP_TTL '(' NUMBER ')'",
"inet_socket_option : KW_IP_TOS '(' NUMBER ')'",
"source_items : source_item ';' source_items",
"source_items :",
"source_item : source_afinter",
"source_item : source_affile",
"source_item : source_afsocket",
"source_item : source_afsyslog",
"source_item : source_afstreams",
"source_item : source_afprogram",
"source_afinter : KW_INTERNAL '(' ')'",
"source_affile : KW_FILE '(' source_affile_params ')'",
"source_affile : KW_PIPE '(' source_afpipe_params ')'",
"$$2 :",
"source_affile_params : string $$2 source_affile_options",
"source_affile_options : source_affile_option source_affile_options",
"source_affile_options :",
"source_affile_option : source_reader_option",
"source_affile_option : KW_LEVEL '(' string ')'",
"source_affile_option : KW_FACILITY '(' string ')'",
"$$3 :",
"source_afpipe_params : string $$3 source_afpipe_options",
"source_afpipe_options : KW_OPTIONAL '(' yesno ')'",
"source_afpipe_options : source_reader_options",
"source_afsocket : KW_UNIX_DGRAM '(' source_afunix_dgram_params ')'",
"source_afsocket : KW_UNIX_STREAM '(' source_afunix_stream_params ')'",
"$$4 :",
"source_afsocket : KW_UDP $$4 '(' source_afinet_udp_params ')'",
"$$5 :",
"source_afsocket : KW_TCP $$5 '(' source_afinet_tcp_params ')'",
"$$6 :",
"source_afsocket : KW_UDP6 $$6 '(' source_afinet_udp_params ')'",
"$$7 :",
"source_afsocket : KW_TCP6 $$7 '(' source_afinet_tcp_params ')'",
"$$8 :",
"source_afunix_dgram_params : string $$8 source_afunix_options",
"$$9 :",
"source_afunix_stream_params : string $$9 source_afunix_options",
"source_afunix_options : source_afunix_option source_afunix_options",
"source_afunix_options :",
"source_afunix_option : KW_OWNER '(' string_or_number ')'",
"source_afunix_option : KW_GROUP '(' string_or_number ')'",
"source_afunix_option : KW_PERM '(' NUMBER ')'",
"source_afunix_option : KW_OPTIONAL '(' yesno ')'",
"source_afunix_option : source_afsocket_stream_params",
"source_afunix_option : source_reader_option",
"source_afunix_option : socket_option",
"$$10 :",
"source_afinet_udp_params : $$10 source_afinet_udp_options",
"source_afinet_udp_options : source_afinet_udp_option source_afinet_udp_options",
"source_afinet_udp_options :",
"source_afinet_udp_option : source_afinet_option",
"source_afinet_option : KW_LOCALIP '(' string ')'",
"source_afinet_option : KW_IP '(' string ')'",
"source_afinet_option : KW_LOCALPORT '(' string_or_number ')'",
"source_afinet_option : KW_PORT '(' string_or_number ')'",
"source_afinet_option : source_reader_option",
"source_afinet_option : inet_socket_option",
"$$11 :",
"source_afinet_tcp_params : $$11 source_afinet_tcp_options",
"source_afinet_tcp_options : source_afinet_tcp_option source_afinet_tcp_options",
"source_afinet_tcp_options :",
"source_afinet_tcp_option : source_afinet_option",
"$$12 :",
"source_afinet_tcp_option : KW_TLS $$12 '(' tls_options ')'",
"source_afinet_tcp_option : source_afsocket_stream_params",
"source_afsocket_stream_params : KW_KEEP_ALIVE '(' yesno ')'",
"source_afsocket_stream_params : KW_MAX_CONNECTIONS '(' NUMBER ')'",
"$$13 :",
"source_afsyslog : KW_SYSLOG $$13 '(' source_afsyslog_params ')'",
"$$14 :",
"source_afsyslog_params : $$14 source_afsyslog_options",
"source_afsyslog_options : source_afsyslog_option source_afsyslog_options",
"source_afsyslog_options :",
"source_afsyslog_option : source_afinet_option",
"source_afsyslog_option : KW_TRANSPORT '(' string ')'",
"source_afsyslog_option : KW_TRANSPORT '(' KW_TCP ')'",
"source_afsyslog_option : KW_TRANSPORT '(' KW_UDP ')'",
"source_afsyslog_option : KW_TRANSPORT '(' KW_TLS ')'",
"$$15 :",
"source_afsyslog_option : KW_TLS $$15 '(' tls_options ')'",
"source_afsyslog_option : source_afsocket_stream_params",
"source_afprogram : KW_PROGRAM '(' source_afprogram_params ')'",
"$$16 :",
"source_afprogram_params : string $$16 source_reader_options",
"source_afstreams : KW_IFDEF",
"source_afstreams : KW_SUN_STREAMS '(' source_afstreams_params ')'",
"source_afstreams : KW_ENDIF",
"$$17 :",
"source_afstreams_params : string $$17 source_afstreams_options",
"source_afstreams_options : source_afstreams_option source_afstreams_options",
"source_afstreams_options :",
"source_afstreams_option : KW_IFDEF",
"source_afstreams_option : KW_DOOR '(' string ')'",
"source_afstreams_option : KW_ENDIF",
"source_reader_options : source_reader_option source_reader_options",
"source_reader_options :",
"source_reader_option : KW_LOG_IW_SIZE '(' NUMBER ')'",
"source_reader_option : KW_CHAIN_HOSTNAMES '(' yesno ')'",
"source_reader_option : KW_NORMALIZE_HOSTNAMES '(' yesno ')'",
"source_reader_option : KW_KEEP_HOSTNAME '(' yesno ')'",
"source_reader_option : KW_USE_FQDN '(' yesno ')'",
"source_reader_option : KW_USE_DNS '(' dnsmode ')'",
"source_reader_option : KW_DNS_CACHE '(' yesno ')'",
"source_reader_option : KW_PROGRAM_OVERRIDE '(' string ')'",
"source_reader_option : KW_HOST_OVERRIDE '(' string ')'",
"source_reader_option : KW_LOG_PREFIX '(' string ')'",
"source_reader_option : KW_TIME_ZONE '(' string ')'",
"source_reader_option : KW_CHECK_HOSTNAME '(' yesno ')'",
"source_reader_option : KW_FLAGS '(' source_reader_option_flags ')'",
"source_reader_option : KW_LOG_MSG_SIZE '(' NUMBER ')'",
"source_reader_option : KW_LOG_FETCH_LIMIT '(' NUMBER ')'",
"source_reader_option : KW_PAD_SIZE '(' NUMBER ')'",
"source_reader_option : KW_FOLLOW_FREQ '(' NUMBER ')'",
"source_reader_option : KW_KEEP_TIMESTAMP '(' yesno ')'",
"source_reader_option : KW_ENCODING '(' string ')'",
"source_reader_option_flags : string source_reader_option_flags",
"source_reader_option_flags :",
"dest_items : dest_item ';' dest_items",
"dest_items :",
"dest_item : dest_affile",
"dest_item : dest_afpipe",
"dest_item : dest_afsocket",
"dest_item : dest_afuser",
"dest_item : dest_afprogram",
"dest_item : dest_afsyslog",
"dest_item : dest_afsql",
"dest_affile : KW_FILE '(' dest_affile_params ')'",
"$$18 :",
"dest_affile_params : string $$18 dest_affile_options",
"dest_affile_options : dest_affile_option dest_affile_options",
"dest_affile_options :",
"dest_affile_option : dest_writer_option",
"dest_affile_option : KW_OPTIONAL '(' yesno ')'",
"dest_affile_option : KW_OWNER '(' string_or_number ')'",
"dest_affile_option : KW_GROUP '(' string_or_number ')'",
"dest_affile_option : KW_PERM '(' NUMBER ')'",
"dest_affile_option : KW_DIR_OWNER '(' string_or_number ')'",
"dest_affile_option : KW_DIR_GROUP '(' string_or_number ')'",
"dest_affile_option : KW_DIR_PERM '(' NUMBER ')'",
"dest_affile_option : KW_CREATE_DIRS '(' yesno ')'",
"dest_affile_option : KW_OVERWRITE_IF_OLDER '(' NUMBER ')'",
"dest_affile_option : KW_FSYNC '(' yesno ')'",
"dest_afpipe : KW_PIPE '(' dest_afpipe_params ')'",
"$$19 :",
"dest_afpipe_params : string $$19 dest_afpipe_options",
"dest_afpipe_options : dest_afpipe_option dest_afpipe_options",
"dest_afpipe_options :",
"dest_afpipe_option : dest_writer_option",
"dest_afpipe_option : KW_OWNER '(' string_or_number ')'",
"dest_afpipe_option : KW_GROUP '(' string_or_number ')'",
"dest_afpipe_option : KW_PERM '(' NUMBER ')'",
"dest_afsocket : KW_UNIX_DGRAM '(' dest_afunix_dgram_params ')'",
"dest_afsocket : KW_UNIX_STREAM '(' dest_afunix_stream_params ')'",
"$$20 :",
"dest_afsocket : KW_UDP $$20 '(' dest_afinet_udp_params ')'",
"$$21 :",
"dest_afsocket : KW_TCP $$21 '(' dest_afinet_tcp_params ')'",
"$$22 :",
"dest_afsocket : KW_UDP6 $$22 '(' dest_afinet_udp_params ')'",
"$$23 :",
"dest_afsocket : KW_TCP6 $$23 '(' dest_afinet_tcp_params ')'",
"$$24 :",
"dest_afunix_dgram_params : string $$24 dest_afunix_options",
"$$25 :",
"dest_afunix_stream_params : string $$25 dest_afunix_options",
"dest_afunix_options : dest_afunix_options dest_afunix_option",
"dest_afunix_options :",
"dest_afunix_option : dest_writer_option",
"dest_afunix_option : dest_afsocket_option",
"dest_afunix_option : socket_option",
"$$26 :",
"dest_afinet_udp_params : string $$26 dest_afinet_udp_options",
"dest_afinet_udp_options : dest_afinet_udp_options dest_afinet_udp_option",
"dest_afinet_udp_options :",
"dest_afinet_option : KW_LOCALIP '(' string ')'",
"dest_afinet_option : KW_LOCALPORT '(' string_or_number ')'",
"dest_afinet_option : KW_PORT '(' string_or_number ')'",
"dest_afinet_option : KW_DESTPORT '(' string_or_number ')'",
"dest_afinet_option : inet_socket_option",
"dest_afinet_option : dest_writer_option",
"dest_afinet_option : dest_afsocket_option",
"dest_afinet_udp_option : dest_afinet_option",
"dest_afinet_udp_option : KW_SPOOF_SOURCE '(' yesno ')'",
"$$27 :",
"dest_afinet_tcp_params : string $$27 dest_afinet_tcp_options",
"dest_afinet_tcp_options : dest_afinet_tcp_options dest_afinet_tcp_option",
"dest_afinet_tcp_options :",
"dest_afinet_tcp_option : dest_afinet_option",
"$$28 :",
"dest_afinet_tcp_option : KW_TLS $$28 '(' tls_options ')'",
"dest_afsocket_option : KW_KEEP_ALIVE '(' yesno ')'",
"dest_afsyslog : KW_SYSLOG '(' dest_afsyslog_params ')'",
"$$29 :",
"dest_afsyslog_params : string $$29 dest_afsyslog_options",
"dest_afsyslog_options : dest_afsyslog_options dest_afsyslog_option",
"dest_afsyslog_options :",
"dest_afsyslog_option : dest_afinet_option",
"dest_afsyslog_option : KW_TRANSPORT '(' string ')'",
"dest_afsyslog_option : KW_TRANSPORT '(' KW_TCP ')'",
"dest_afsyslog_option : KW_TRANSPORT '(' KW_UDP ')'",
"dest_afsyslog_option : KW_TRANSPORT '(' KW_TLS ')'",
"dest_afsyslog_option : KW_SPOOF_SOURCE '(' yesno ')'",
"$$30 :",
"dest_afsyslog_option : KW_TLS $$30 '(' tls_options ')'",
"dest_afuser : KW_USERTTY '(' string ')'",
"dest_afprogram : KW_PROGRAM '(' dest_afprogram_params ')'",
"$$31 :",
"dest_afprogram_params : string $$31 dest_writer_options",
"dest_afsql : KW_SQL '(' dest_afsql_params ')'",
"$$32 :",
"dest_afsql_params : $$32 dest_afsql_options",
"dest_afsql_options : dest_afsql_option dest_afsql_options",
"dest_afsql_options :",
"dest_afsql_option : KW_IFDEF",
"dest_afsql_option : KW_TYPE '(' string ')'",
"dest_afsql_option : KW_HOST '(' string ')'",
"dest_afsql_option : KW_PORT '(' string_or_number ')'",
"dest_afsql_option : KW_USERNAME '(' string ')'",
"dest_afsql_option : KW_PASSWORD '(' string ')'",
"dest_afsql_option : KW_DATABASE '(' string ')'",
"dest_afsql_option : KW_TABLE '(' string ')'",
"dest_afsql_option : KW_COLUMNS '(' string_list ')'",
"dest_afsql_option : KW_INDEXES '(' string_list ')'",
"dest_afsql_option : KW_VALUES '(' string_list ')'",
"dest_afsql_option : KW_LOG_FIFO_SIZE '(' NUMBER ')'",
"dest_afsql_option : KW_LOG_DISK_FIFO_SIZE '(' NUMBER ')'",
"dest_afsql_option : KW_FRAC_DIGITS '(' NUMBER ')'",
"dest_afsql_option : KW_TIME_ZONE '(' string ')'",
"dest_afsql_option : KW_ENDIF",
"dest_writer_options : dest_writer_option dest_writer_options",
"dest_writer_options :",
"dest_writer_option : KW_FLAGS '(' dest_writer_options_flags ')'",
"dest_writer_option : KW_LOG_FIFO_SIZE '(' NUMBER ')'",
"dest_writer_option : KW_FLUSH_LINES '(' NUMBER ')'",
"dest_writer_option : KW_FLUSH_TIMEOUT '(' NUMBER ')'",
"dest_writer_option : KW_SUPPRESS '(' NUMBER ')'",
"dest_writer_option : KW_TEMPLATE '(' string ')'",
"dest_writer_option : KW_TEMPLATE_ESCAPE '(' yesno ')'",
"dest_writer_option : KW_TIME_ZONE '(' string ')'",
"dest_writer_option : KW_TS_FORMAT '(' string ')'",
"dest_writer_option : KW_FRAC_DIGITS '(' NUMBER ')'",
"dest_writer_option : KW_THROTTLE '(' NUMBER ')'",
"dest_writer_options_flags : string dest_writer_options_flags",
"dest_writer_options_flags :",
"options_items : options_item ';' options_items",
"options_items :",
"options_item : KW_MARK_FREQ '(' NUMBER ')'",
"options_item : KW_STATS_FREQ '(' NUMBER ')'",
"options_item : KW_STATS_LEVEL '(' NUMBER ')'",
"options_item : KW_FLUSH_LINES '(' NUMBER ')'",
"options_item : KW_FLUSH_TIMEOUT '(' NUMBER ')'",
"options_item : KW_CHAIN_HOSTNAMES '(' yesno ')'",
"options_item : KW_NORMALIZE_HOSTNAMES '(' yesno ')'",
"options_item : KW_KEEP_HOSTNAME '(' yesno ')'",
"options_item : KW_CHECK_HOSTNAME '(' yesno ')'",
"options_item : KW_BAD_HOSTNAME '(' STRING ')'",
"options_item : KW_USE_TIME_RECVD '(' yesno ')'",
"options_item : KW_USE_FQDN '(' yesno ')'",
"options_item : KW_USE_DNS '(' dnsmode ')'",
"options_item : KW_TIME_REOPEN '(' NUMBER ')'",
"options_item : KW_TIME_REAP '(' NUMBER ')'",
"options_item : KW_TIME_SLEEP '(' NUMBER ')'",
"options_item : KW_LOG_FIFO_SIZE '(' NUMBER ')'",
"options_item : KW_LOG_IW_SIZE '(' NUMBER ')'",
"options_item : KW_LOG_FETCH_LIMIT '(' NUMBER ')'",
"options_item : KW_LOG_MSG_SIZE '(' NUMBER ')'",
"options_item : KW_KEEP_TIMESTAMP '(' yesno ')'",
"options_item : KW_TS_FORMAT '(' string ')'",
"options_item : KW_FRAC_DIGITS '(' NUMBER ')'",
"options_item : KW_GC_BUSY_THRESHOLD '(' NUMBER ')'",
"options_item : KW_GC_IDLE_THRESHOLD '(' NUMBER ')'",
"options_item : KW_CREATE_DIRS '(' yesno ')'",
"options_item : KW_OWNER '(' string_or_number ')'",
"options_item : KW_GROUP '(' string_or_number ')'",
"options_item : KW_PERM '(' NUMBER ')'",
"options_item : KW_DIR_OWNER '(' string_or_number ')'",
"options_item : KW_DIR_GROUP '(' string_or_number ')'",
"options_item : KW_DIR_PERM '(' NUMBER ')'",
"options_item : KW_DNS_CACHE '(' yesno ')'",
"options_item : KW_DNS_CACHE_SIZE '(' NUMBER ')'",
"options_item : KW_DNS_CACHE_EXPIRE '(' NUMBER ')'",
"options_item : KW_DNS_CACHE_EXPIRE_FAILED '(' NUMBER ')'",
"options_item : KW_DNS_CACHE_HOSTS '(' string ')'",
"options_item : KW_FILE_TEMPLATE '(' string ')'",
"options_item : KW_PROTO_TEMPLATE '(' string ')'",
"options_item : KW_RECV_TIME_ZONE '(' string ')'",
"options_item : KW_SEND_TIME_ZONE '(' string ')'",
"tls_options : tls_option tls_options",
"tls_options :",
"tls_option : KW_IFDEF",
"tls_option : KW_PEER_VERIFY '(' string ')'",
"tls_option : KW_KEY_FILE '(' string ')'",
"tls_option : KW_CERT_FILE '(' string ')'",
"tls_option : KW_CA_DIR '(' string ')'",
"tls_option : KW_CRL_DIR '(' string ')'",
"tls_option : KW_TRUSTED_KEYS '(' string_list ')'",
"tls_option : KW_TRUSTED_DN '(' string_list ')'",
"tls_option : KW_ENDIF",
"filter_expr : filter_simple_expr",
"filter_expr : KW_NOT filter_expr",
"filter_expr : filter_expr KW_OR filter_expr",
"filter_expr : filter_expr KW_AND filter_expr",
"filter_expr : '(' filter_expr ')'",
"filter_simple_expr : KW_FACILITY '(' filter_fac_list ')'",
"filter_simple_expr : KW_FACILITY '(' NUMBER ')'",
"filter_simple_expr : KW_LEVEL '(' filter_level_list ')'",
"filter_simple_expr : KW_FILTER '(' string ')'",
"filter_simple_expr : KW_NETMASK '(' string ')'",
"$$33 :",
"filter_simple_expr : KW_PROGRAM '(' string $$33 filter_re_opts ')'",
"$$34 :",
"filter_simple_expr : KW_HOST '(' string $$34 filter_re_opts ')'",
"$$35 :",
"filter_simple_expr : KW_MATCH '(' string $$35 filter_match_opts ')'",
"$$36 :",
"filter_simple_expr : KW_MESSAGE '(' string $$36 filter_re_opts ')'",
"$$37 :",
"filter_simple_expr : KW_SOURCE '(' string $$37 filter_re_opts ')'",
"filter_match_opts : filter_match_opt filter_match_opts",
"filter_match_opts :",
"filter_match_opt : filter_re_opt",
"filter_match_opt : KW_VALUE '(' string ')'",
"filter_re_opts : filter_re_opt filter_re_opts",
"filter_re_opts :",
"filter_re_opt : KW_TYPE '(' string ')'",
"filter_re_opt : KW_FLAGS '(' regexp_option_flags ')'",
"regexp_option_flags : string regexp_option_flags",
"regexp_option_flags :",
"filter_fac_list : filter_fac filter_fac_list",
"filter_fac_list : filter_fac",
"filter_fac : string",
"filter_level_list : filter_level filter_level_list",
"filter_level_list : filter_level",
"filter_level : string DOTDOT string",
"filter_level : string",
"$$38 :",
"parser_expr : KW_CSV_PARSER '(' $$38 parser_csv_opts ')'",
"$$39 :",
"parser_expr : KW_DB_PARSER '(' $$39 parser_db_opts ')'",
"parser_db_opts : parser_db_opt parser_db_opts",
"parser_db_opts :",
"parser_db_opt : KW_FILE '(' string ')'",
"parser_column_opt : parser_opt",
"parser_column_opt : KW_COLUMNS '(' string_list ')'",
"parser_opt : KW_TEMPLATE '(' string ')'",
"parser_csv_opts : parser_csv_opt parser_csv_opts",
"parser_csv_opts :",
"parser_csv_opt : parser_column_opt",
"parser_csv_opt : KW_FLAGS '(' parser_csv_flags ')'",
"parser_csv_opt : KW_DELIMITERS '(' string ')'",
"parser_csv_opt : KW_QUOTES '(' string ')'",
"parser_csv_opt : KW_QUOTE_PAIRS '(' string ')'",
"parser_csv_opt : KW_NULL '(' string ')'",
"parser_csv_flags : string parser_csv_flags",
"parser_csv_flags :",
"rewrite_expr_list : rewrite_expr_list_build",
"rewrite_expr_list_build : rewrite_expr rewrite_expr_list_build",
"rewrite_expr_list_build :",
"$$40 :",
"rewrite_expr : KW_SUBST '(' string string $$40 rewrite_expr_opts ')' ';'",
"$$41 :",
"rewrite_expr : KW_SET '(' string $$41 rewrite_expr_opts ')' ';'",
"rewrite_expr_opts : rewrite_expr_opt rewrite_expr_opts",
"rewrite_expr_opts :",
"rewrite_expr_opt : KW_VALUE '(' string ')'",
"rewrite_expr_opt : KW_TYPE '(' string ')'",
"rewrite_expr_opt : KW_FLAGS '(' regexp_option_flags ')'",
"yesno : KW_YES",
"yesno : KW_NO",
"yesno : NUMBER",
"dnsmode : yesno",
"dnsmode : KW_PERSIST_ONLY",
"string : IDENTIFIER",
"string : STRING",
"string_or_number : string",
"string_or_number : NUMBER",
"string_list : string_list_build",
"string_list_build : string string_list_build",
"string_list_build :",
};
#endif
#if YYDEBUG
#include <stdio.h>
#endif
#ifdef YYSTACKSIZE
#undef YYMAXDEPTH
#define YYMAXDEPTH YYSTACKSIZE
#else
#ifdef YYMAXDEPTH
#define YYSTACKSIZE YYMAXDEPTH
#else
#define YYSTACKSIZE 10000
#define YYMAXDEPTH 10000
#endif
#endif
#define YYINITSTACKSIZE 200
int yydebug;
int yynerrs;
int yyerrflag;
int yychar;
short *yyssp;
YYSTYPE *yyvsp;
YYSTYPE yyval;
YYSTYPE yylval;
short *yyss;
short *yysslim;
YYSTYPE *yyvs;
int yystacksize;
#line 1480 "cfg-grammar.y"

extern int linenum;

void 
yyerror(char *msg)
{
  fprintf(stderr, "%s in %s at line %d.\n", msg, configuration->filename, linenum);
}

void
yyparser_reset(void)
{
  last_driver = NULL;
  last_reader_options = NULL;
  last_writer_options = NULL;
  last_template = NULL;
}
#line 1517 "cfg-grammar.c"
/* allocate initial stack or double stack size, up to YYMAXDEPTH */
static int yygrowstack()
{
    int newsize, i;
    short *newss;
    YYSTYPE *newvs;

    if ((newsize = yystacksize) == 0)
        newsize = YYINITSTACKSIZE;
    else if (newsize >= YYMAXDEPTH)
        return -1;
    else if ((newsize *= 2) > YYMAXDEPTH)
        newsize = YYMAXDEPTH;
    i = yyssp - yyss;
    newss = yyss ? (short *)realloc(yyss, newsize * sizeof *newss) :
      (short *)malloc(newsize * sizeof *newss);
    if (newss == NULL)
        return -1;
    yyss = newss;
    yyssp = newss + i;
    newvs = yyvs ? (YYSTYPE *)realloc(yyvs, newsize * sizeof *newvs) :
      (YYSTYPE *)malloc(newsize * sizeof *newvs);
    if (newvs == NULL)
        return -1;
    yyvs = newvs;
    yyvsp = newvs + i;
    yystacksize = newsize;
    yysslim = yyss + newsize - 1;
    return 0;
}

#define YYABORT goto yyabort
#define YYREJECT goto yyabort
#define YYACCEPT goto yyaccept
#define YYERROR goto yyerrlab

#ifndef YYPARSE_PARAM
#if defined(__cplusplus) || __STDC__
#define YYPARSE_PARAM_ARG void
#define YYPARSE_PARAM_DECL
#else	/* ! ANSI-C/C++ */
#define YYPARSE_PARAM_ARG
#define YYPARSE_PARAM_DECL
#endif	/* ANSI-C/C++ */
#else	/* YYPARSE_PARAM */
#ifndef YYPARSE_PARAM_TYPE
#define YYPARSE_PARAM_TYPE void *
#endif
#if defined(__cplusplus) || __STDC__
#define YYPARSE_PARAM_ARG YYPARSE_PARAM_TYPE YYPARSE_PARAM
#define YYPARSE_PARAM_DECL
#else	/* ! ANSI-C/C++ */
#define YYPARSE_PARAM_ARG YYPARSE_PARAM
#define YYPARSE_PARAM_DECL YYPARSE_PARAM_TYPE YYPARSE_PARAM;
#endif	/* ANSI-C/C++ */
#endif	/* ! YYPARSE_PARAM */

int
yyparse (YYPARSE_PARAM_ARG)
    YYPARSE_PARAM_DECL
{
    register int yym, yyn, yystate;
#if YYDEBUG
    register const char *yys;

    if ((yys = getenv("YYDEBUG")))
    {
        yyn = *yys;
        if (yyn >= '0' && yyn <= '9')
            yydebug = yyn - '0';
    }
#endif

    yynerrs = 0;
    yyerrflag = 0;
    yychar = (-1);

    if (yyss == NULL && yygrowstack()) goto yyoverflow;
    yyssp = yyss;
    yyvsp = yyvs;
    *yyssp = yystate = 0;

yyloop:
    if ((yyn = yydefred[yystate])) goto yyreduce;
    if (yychar < 0)
    {
        if ((yychar = yylex()) < 0) yychar = 0;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, reading %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
    }
    if ((yyn = yysindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: state %d, shifting to state %d\n",
                    YYPREFIX, yystate, yytable[yyn]);
#endif
        if (yyssp >= yysslim && yygrowstack())
        {
            goto yyoverflow;
        }
        *++yyssp = yystate = yytable[yyn];
        *++yyvsp = yylval;
        yychar = (-1);
        if (yyerrflag > 0)  --yyerrflag;
        goto yyloop;
    }
    if ((yyn = yyrindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
        yyn = yytable[yyn];
        goto yyreduce;
    }
    if (yyerrflag) goto yyinrecovery;
#if defined(lint) || defined(__GNUC__)
    goto yynewerror;
#endif
yynewerror:
    yyerror("syntax error");
#if defined(lint) || defined(__GNUC__)
    goto yyerrlab;
#endif
yyerrlab:
    ++yynerrs;
yyinrecovery:
    if (yyerrflag < 3)
    {
        yyerrflag = 3;
        for (;;)
        {
            if ((yyn = yysindex[*yyssp]) && (yyn += YYERRCODE) >= 0 &&
                    yyn <= YYTABLESIZE && yycheck[yyn] == YYERRCODE)
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: state %d, error recovery shifting\
 to state %d\n", YYPREFIX, *yyssp, yytable[yyn]);
#endif
                if (yyssp >= yysslim && yygrowstack())
                {
                    goto yyoverflow;
                }
                *++yyssp = yystate = yytable[yyn];
                *++yyvsp = yylval;
                goto yyloop;
            }
            else
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: error recovery discarding state %d\n",
                            YYPREFIX, *yyssp);
#endif
                if (yyssp <= yyss) goto yyabort;
                --yyssp;
                --yyvsp;
            }
        }
    }
    else
    {
        if (yychar == 0) goto yyabort;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, error recovery discards token %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
        yychar = (-1);
        goto yyloop;
    }
yyreduce:
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: state %d, reducing by rule %d (%s)\n",
                YYPREFIX, yystate, yyn, yyrule[yyn]);
#endif
    yym = yylen[yyn];
    yyval = yyvsp[1-yym];
    switch (yyn)
    {
case 4:
#line 291 "cfg-grammar.y"
{ cfg_add_source(configuration, yyvsp[0].ptr); }
break;
case 5:
#line 292 "cfg-grammar.y"
{ cfg_add_dest(configuration, yyvsp[0].ptr); }
break;
case 6:
#line 293 "cfg-grammar.y"
{ cfg_add_connection(configuration, yyvsp[0].ptr); }
break;
case 7:
#line 294 "cfg-grammar.y"
{ cfg_add_filter(configuration, yyvsp[0].ptr); }
break;
case 8:
#line 295 "cfg-grammar.y"
{ cfg_add_parser(configuration, yyvsp[0].ptr); }
break;
case 9:
#line 296 "cfg-grammar.y"
{ cfg_add_rewrite(configuration, yyvsp[0].ptr); }
break;
case 10:
#line 297 "cfg-grammar.y"
{ cfg_add_template(configuration, yyvsp[0].ptr); }
break;
case 11:
#line 298 "cfg-grammar.y"
{  }
break;
case 12:
#line 302 "cfg-grammar.y"
{ yyval.ptr = log_source_group_new(yyvsp[-3].cptr, yyvsp[-1].ptr); free(yyvsp[-3].cptr); }
break;
case 13:
#line 306 "cfg-grammar.y"
{ yyval.ptr = log_filter_rule_new(yyvsp[-4].cptr, yyvsp[-2].node); free(yyvsp[-4].cptr); }
break;
case 14:
#line 310 "cfg-grammar.y"
{ yyval.ptr = log_parser_rule_new(yyvsp[-4].cptr, yyvsp[-2].ptr); free(yyvsp[-4].cptr); }
break;
case 15:
#line 313 "cfg-grammar.y"
{ yyval.ptr = log_rewrite_rule_new(yyvsp[-3].cptr, yyvsp[-1].ptr); free(yyvsp[-3].cptr); }
break;
case 16:
#line 316 "cfg-grammar.y"
{ yyval.ptr = log_dest_group_new(yyvsp[-3].cptr, yyvsp[-1].ptr); free(yyvsp[-3].cptr); }
break;
case 17:
#line 320 "cfg-grammar.y"
{ LogPipeItem *pi = log_pipe_item_append_tail(yyvsp[-3].ptr, yyvsp[-2].ptr); yyval.ptr = log_connection_new(pi, yyvsp[-1].num); }
break;
case 18:
#line 324 "cfg-grammar.y"
{ log_pipe_item_append(yyvsp[-2].ptr, yyvsp[0].ptr); yyval.ptr = yyvsp[-2].ptr; }
break;
case 19:
#line 325 "cfg-grammar.y"
{ yyval.ptr = NULL; }
break;
case 20:
#line 329 "cfg-grammar.y"
{ yyval.ptr = log_pipe_item_new(EP_SOURCE, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 21:
#line 330 "cfg-grammar.y"
{ yyval.ptr = log_pipe_item_new(EP_FILTER, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 22:
#line 331 "cfg-grammar.y"
{ yyval.ptr = log_pipe_item_new(EP_PARSER, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 23:
#line 332 "cfg-grammar.y"
{ yyval.ptr = log_pipe_item_new(EP_REWRITE, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 24:
#line 333 "cfg-grammar.y"
{ yyval.ptr = log_pipe_item_new(EP_DESTINATION, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 25:
#line 337 "cfg-grammar.y"
{ log_pipe_item_append(yyvsp[-1].ptr, yyvsp[0].ptr); yyval.ptr = yyvsp[-1].ptr; }
break;
case 26:
#line 338 "cfg-grammar.y"
{ yyval.ptr = NULL; }
break;
case 27:
#line 342 "cfg-grammar.y"
{ LogPipeItem *pi = log_pipe_item_append_tail(yyvsp[-4].ptr, yyvsp[-3].ptr); yyval.ptr = log_pipe_item_new_ref(EP_PIPE, log_connection_new(pi, yyvsp[-2].num)); }
break;
case 28:
#line 346 "cfg-grammar.y"
{ yyval.num = yyvsp[-2].num; }
break;
case 29:
#line 347 "cfg-grammar.y"
{ yyval.num = 0; }
break;
case 30:
#line 352 "cfg-grammar.y"
{ yyval.num = log_connection_lookup_flag(yyvsp[-1].cptr) | yyvsp[0].num; free(yyvsp[-1].cptr); }
break;
case 31:
#line 353 "cfg-grammar.y"
{ yyval.num = 0; }
break;
case 32:
#line 358 "cfg-grammar.y"
{ yyval.ptr = NULL; }
break;
case 33:
#line 363 "cfg-grammar.y"
{
	    last_template = log_template_new(yyvsp[0].cptr, NULL);
	    free(yyvsp[0].cptr);
	  }
break;
case 34:
#line 367 "cfg-grammar.y"
{ yyval.ptr = last_template;  }
break;
case 37:
#line 376 "cfg-grammar.y"
{ last_template->template = g_strdup(yyvsp[-1].cptr); free(yyvsp[-1].cptr); if (!cfg_check_template(last_template)) { YYERROR; } }
break;
case 38:
#line 377 "cfg-grammar.y"
{ log_template_set_escape(last_template, yyvsp[-1].num); }
break;
case 39:
#line 381 "cfg-grammar.y"
{ last_sock_options->sndbuf = yyvsp[-1].num; }
break;
case 40:
#line 382 "cfg-grammar.y"
{ last_sock_options->rcvbuf = yyvsp[-1].num; }
break;
case 41:
#line 383 "cfg-grammar.y"
{ last_sock_options->broadcast = yyvsp[-1].num; }
break;
case 42:
#line 384 "cfg-grammar.y"
{ last_sock_options->keepalive = yyvsp[-1].num; }
break;
case 44:
#line 389 "cfg-grammar.y"
{ ((InetSocketOptions *) last_sock_options)->ttl = yyvsp[-1].num; }
break;
case 45:
#line 390 "cfg-grammar.y"
{ ((InetSocketOptions *) last_sock_options)->tos = yyvsp[-1].num; }
break;
case 46:
#line 394 "cfg-grammar.y"
{ if (yyvsp[-2].ptr) {log_drv_append(yyvsp[-2].ptr, yyvsp[0].ptr); log_drv_unref(yyvsp[0].ptr); yyval.ptr = yyvsp[-2].ptr; } else { YYERROR; } }
break;
case 47:
#line 395 "cfg-grammar.y"
{ yyval.ptr = NULL; }
break;
case 48:
#line 399 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; }
break;
case 49:
#line 400 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; }
break;
case 50:
#line 401 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; }
break;
case 51:
#line 402 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; }
break;
case 52:
#line 403 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; }
break;
case 53:
#line 404 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; }
break;
case 54:
#line 408 "cfg-grammar.y"
{ yyval.ptr = afinter_sd_new(); }
break;
case 55:
#line 412 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 56:
#line 413 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 57:
#line 418 "cfg-grammar.y"
{
	    last_driver = affile_sd_new(yyvsp[0].cptr, 0); 
	    free(yyvsp[0].cptr); 
	    last_reader_options = &((AFFileSourceDriver *) last_driver)->reader_options;
	  }
break;
case 58:
#line 423 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 61:
#line 432 "cfg-grammar.y"
{}
break;
case 62:
#line 434 "cfg-grammar.y"
{ 
            int level = -1;
            level = syslog_name_lookup_level_by_name(yyvsp[-1].cptr);
	    if (level == -1)
	      msg_error("Warning: Unknown priority level",
                        evt_tag_str("priority", yyvsp[-1].cptr),
                        NULL);
            else
              affile_sd_set_pri_level(last_driver, level); 
            free(yyvsp[-1].cptr);
          }
break;
case 63:
#line 447 "cfg-grammar.y"
{
            int facility = -1;
            facility = syslog_name_lookup_facility_by_name(yyvsp[-1].cptr);
 	    if (facility == -1)
	      msg_error("Warning: Unknown facility level",
                        evt_tag_str("facility", yyvsp[-1].cptr),
                        NULL);
            else
	      affile_sd_set_pri_facility(last_driver, facility); 
            free(yyvsp[-1].cptr);
          }
break;
case 64:
#line 462 "cfg-grammar.y"
{
	    last_driver = affile_sd_new(yyvsp[0].cptr, AFFILE_PIPE); 
	    free(yyvsp[0].cptr); 
	    last_reader_options = &((AFFileSourceDriver *) last_driver)->reader_options;
	  }
break;
case 65:
#line 467 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 66:
#line 471 "cfg-grammar.y"
{ last_driver->optional = yyvsp[-1].num; }
break;
case 67:
#line 472 "cfg-grammar.y"
{}
break;
case 68:
#line 476 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 69:
#line 477 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 70:
#line 478 "cfg-grammar.y"
{ last_addr_family = AF_INET; }
break;
case 71:
#line 478 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 72:
#line 479 "cfg-grammar.y"
{ last_addr_family = AF_INET; }
break;
case 73:
#line 479 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 74:
#line 480 "cfg-grammar.y"
{ last_addr_family = AF_INET6; }
break;
case 75:
#line 480 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 76:
#line 481 "cfg-grammar.y"
{ last_addr_family = AF_INET6; }
break;
case 77:
#line 481 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 78:
#line 486 "cfg-grammar.y"
{ 
	    last_driver = afunix_sd_new(
		yyvsp[0].cptr,
		AFSOCKET_DGRAM | AFSOCKET_LOCAL); 
	    free(yyvsp[0].cptr); 
	    last_reader_options = &((AFSocketSourceDriver *) last_driver)->reader_options;
	    last_sock_options = &((AFUnixSourceDriver *) last_driver)->sock_options;
	  }
break;
case 79:
#line 494 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 80:
#line 499 "cfg-grammar.y"
{ 
	    last_driver = afunix_sd_new(
		yyvsp[0].cptr,
		AFSOCKET_STREAM | AFSOCKET_KEEP_ALIVE | AFSOCKET_LOCAL);
	    free(yyvsp[0].cptr);
	    last_reader_options = &((AFSocketSourceDriver *) last_driver)->reader_options;
	    last_sock_options = &((AFUnixSourceDriver *) last_driver)->sock_options;
	  }
break;
case 81:
#line 507 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 84:
#line 517 "cfg-grammar.y"
{ afunix_sd_set_uid(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 85:
#line 518 "cfg-grammar.y"
{ afunix_sd_set_gid(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 86:
#line 519 "cfg-grammar.y"
{ afunix_sd_set_perm(last_driver, yyvsp[-1].num); }
break;
case 87:
#line 520 "cfg-grammar.y"
{ last_driver->optional = yyvsp[-1].num; }
break;
case 88:
#line 521 "cfg-grammar.y"
{}
break;
case 89:
#line 522 "cfg-grammar.y"
{}
break;
case 90:
#line 523 "cfg-grammar.y"
{}
break;
case 91:
#line 528 "cfg-grammar.y"
{ 
	    last_driver = afinet_sd_new(last_addr_family,
			NULL, 514,
			AFSOCKET_DGRAM);
	    last_reader_options = &((AFSocketSourceDriver *) last_driver)->reader_options;
	    last_sock_options = &((AFInetSourceDriver *) last_driver)->sock_options.super;
	  }
break;
case 92:
#line 535 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 96:
#line 548 "cfg-grammar.y"
{ afinet_sd_set_localip(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 97:
#line 549 "cfg-grammar.y"
{ afinet_sd_set_localip(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 98:
#line 550 "cfg-grammar.y"
{ afinet_sd_set_localport(last_driver, yyvsp[-1].cptr, afinet_sd_get_proto_name(last_driver)); free(yyvsp[-1].cptr); }
break;
case 99:
#line 551 "cfg-grammar.y"
{ afinet_sd_set_localport(last_driver, yyvsp[-1].cptr, afinet_sd_get_proto_name(last_driver)); free(yyvsp[-1].cptr); }
break;
case 102:
#line 558 "cfg-grammar.y"
{ 
	    last_driver = afinet_sd_new(last_addr_family,
			NULL, 514,
			AFSOCKET_STREAM);
	    last_reader_options = &((AFSocketSourceDriver *) last_driver)->reader_options;
	    last_sock_options = &((AFInetSourceDriver *) last_driver)->sock_options.super;
	  }
break;
case 103:
#line 565 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 107:
#line 577 "cfg-grammar.y"
{
#if ENABLE_SSL
	    last_tls_context = tls_context_new(TM_SERVER);
#endif
	  }
break;
case 108:
#line 583 "cfg-grammar.y"
{ 
#if ENABLE_SSL
	    afsocket_sd_set_tls_context(last_driver, last_tls_context); 
#endif
          }
break;
case 109:
#line 589 "cfg-grammar.y"
{}
break;
case 110:
#line 593 "cfg-grammar.y"
{ afsocket_sd_set_keep_alive(last_driver, yyvsp[-1].num); }
break;
case 111:
#line 594 "cfg-grammar.y"
{ afsocket_sd_set_max_connections(last_driver, yyvsp[-1].num); }
break;
case 112:
#line 598 "cfg-grammar.y"
{ last_addr_family = AF_INET; }
break;
case 113:
#line 598 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 114:
#line 603 "cfg-grammar.y"
{ 
	    last_driver = afinet_sd_new(last_addr_family,
			NULL, 601,
			AFSOCKET_STREAM | AFSOCKET_SYSLOG_PROTOCOL);
	    last_reader_options = &((AFSocketSourceDriver *) last_driver)->reader_options;
	    last_sock_options = &((AFInetSourceDriver *) last_driver)->sock_options.super;
	  }
break;
case 115:
#line 610 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 119:
#line 620 "cfg-grammar.y"
{ afinet_sd_set_transport(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 120:
#line 621 "cfg-grammar.y"
{ afinet_sd_set_transport(last_driver, "tcp"); }
break;
case 121:
#line 622 "cfg-grammar.y"
{ afinet_sd_set_transport(last_driver, "udp"); }
break;
case 122:
#line 623 "cfg-grammar.y"
{ afinet_sd_set_transport(last_driver, "tls"); }
break;
case 123:
#line 625 "cfg-grammar.y"
{
#if ENABLE_SSL
	    last_tls_context = tls_context_new(TM_SERVER);
#endif
	  }
break;
case 124:
#line 631 "cfg-grammar.y"
{ 
#if ENABLE_SSL
	    afsocket_sd_set_tls_context(last_driver, last_tls_context); 
#endif
          }
break;
case 125:
#line 636 "cfg-grammar.y"
{}
break;
case 126:
#line 640 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 127:
#line 645 "cfg-grammar.y"
{ 
	    last_driver = afprogram_sd_new(yyvsp[0].cptr); 
	    free(yyvsp[0].cptr); 
	    last_reader_options = &((AFProgramSourceDriver *) last_driver)->reader_options;
	  }
break;
case 128:
#line 650 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 129:
#line 654 "cfg-grammar.y"
{
#if ENABLE_SUN_STREAMS
}
break;
case 130:
#line 657 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 131:
#line 658 "cfg-grammar.y"
{
#endif
}
break;
case 132:
#line 665 "cfg-grammar.y"
{ 
#if ENABLE_SUN_STREAMS
	    last_driver = afstreams_sd_new(yyvsp[0].cptr); 
	    free(yyvsp[0].cptr); 
#endif
	  }
break;
case 133:
#line 671 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 136:
#line 680 "cfg-grammar.y"
{
#if ENABLE_SUN_STREAMS
}
break;
case 137:
#line 683 "cfg-grammar.y"
{ afstreams_sd_set_sundoor(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 138:
#line 684 "cfg-grammar.y"
{
#endif
}
break;
case 141:
#line 695 "cfg-grammar.y"
{ last_reader_options->super.init_window_size = yyvsp[-1].num; }
break;
case 142:
#line 696 "cfg-grammar.y"
{ last_reader_options->super.chain_hostnames = yyvsp[-1].num; }
break;
case 143:
#line 697 "cfg-grammar.y"
{ last_reader_options->super.normalize_hostnames = yyvsp[-1].num; }
break;
case 144:
#line 698 "cfg-grammar.y"
{ last_reader_options->super.keep_hostname = yyvsp[-1].num; }
break;
case 145:
#line 699 "cfg-grammar.y"
{ last_reader_options->super.use_fqdn = yyvsp[-1].num; }
break;
case 146:
#line 700 "cfg-grammar.y"
{ last_reader_options->super.use_dns = yyvsp[-1].num; }
break;
case 147:
#line 701 "cfg-grammar.y"
{ last_reader_options->super.use_dns_cache = yyvsp[-1].num; }
break;
case 148:
#line 702 "cfg-grammar.y"
{ last_reader_options->super.program_override = g_strdup(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 149:
#line 703 "cfg-grammar.y"
{ last_reader_options->super.host_override = g_strdup(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 150:
#line 704 "cfg-grammar.y"
{ gchar *p = strrchr(yyvsp[-1].cptr, ':'); if (p) *p = 0; last_reader_options->super.program_override = g_strdup(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 151:
#line 705 "cfg-grammar.y"
{ last_reader_options->time_zone_string = g_strdup(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 152:
#line 706 "cfg-grammar.y"
{ last_reader_options->check_hostname = yyvsp[-1].num; }
break;
case 153:
#line 707 "cfg-grammar.y"
{ last_reader_options->options = yyvsp[-1].num; }
break;
case 154:
#line 708 "cfg-grammar.y"
{ last_reader_options->msg_size = yyvsp[-1].num; }
break;
case 155:
#line 709 "cfg-grammar.y"
{ last_reader_options->fetch_limit = yyvsp[-1].num; }
break;
case 156:
#line 710 "cfg-grammar.y"
{ last_reader_options->padding = yyvsp[-1].num; }
break;
case 157:
#line 711 "cfg-grammar.y"
{ last_reader_options->follow_freq = yyvsp[-1].num; }
break;
case 158:
#line 712 "cfg-grammar.y"
{ last_reader_options->super.keep_timestamp = yyvsp[-1].num; }
break;
case 159:
#line 713 "cfg-grammar.y"
{ last_reader_options->text_encoding = g_strdup(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 160:
#line 717 "cfg-grammar.y"
{ yyval.num = log_reader_options_lookup_flag(yyvsp[-1].cptr) | yyvsp[0].num; free(yyvsp[-1].cptr); }
break;
case 161:
#line 718 "cfg-grammar.y"
{ yyval.num = 0; }
break;
case 162:
#line 723 "cfg-grammar.y"
{ log_drv_append(yyvsp[-2].ptr, yyvsp[0].ptr); log_drv_unref(yyvsp[0].ptr); yyval.ptr = yyvsp[-2].ptr; }
break;
case 163:
#line 724 "cfg-grammar.y"
{ yyval.ptr = NULL; }
break;
case 164:
#line 728 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; }
break;
case 165:
#line 729 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; }
break;
case 166:
#line 730 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; }
break;
case 167:
#line 731 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; }
break;
case 168:
#line 732 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; }
break;
case 169:
#line 733 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; }
break;
case 170:
#line 735 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; }
break;
case 171:
#line 740 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 172:
#line 745 "cfg-grammar.y"
{ 
	    last_driver = affile_dd_new(yyvsp[0].cptr, 0); 
	    free(yyvsp[0].cptr); 
	    last_writer_options = &((AFFileDestDriver *) last_driver)->writer_options;
	  }
break;
case 173:
#line 751 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 177:
#line 761 "cfg-grammar.y"
{ last_driver->optional = yyvsp[-1].num; }
break;
case 178:
#line 762 "cfg-grammar.y"
{ affile_dd_set_file_uid(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 179:
#line 763 "cfg-grammar.y"
{ affile_dd_set_file_gid(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 180:
#line 764 "cfg-grammar.y"
{ affile_dd_set_file_perm(last_driver, yyvsp[-1].num); }
break;
case 181:
#line 765 "cfg-grammar.y"
{ affile_dd_set_dir_uid(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 182:
#line 766 "cfg-grammar.y"
{ affile_dd_set_dir_gid(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 183:
#line 767 "cfg-grammar.y"
{ affile_dd_set_dir_perm(last_driver, yyvsp[-1].num); }
break;
case 184:
#line 768 "cfg-grammar.y"
{ affile_dd_set_create_dirs(last_driver, yyvsp[-1].num); }
break;
case 185:
#line 769 "cfg-grammar.y"
{ affile_dd_set_overwrite_if_older(last_driver, yyvsp[-1].num); }
break;
case 186:
#line 770 "cfg-grammar.y"
{ affile_dd_set_fsync(last_driver, yyvsp[-1].num); }
break;
case 187:
#line 774 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 188:
#line 779 "cfg-grammar.y"
{ 
	    last_driver = affile_dd_new(yyvsp[0].cptr, AFFILE_NO_EXPAND | AFFILE_PIPE);
	    free(yyvsp[0].cptr); 
	    last_writer_options = &((AFFileDestDriver *) last_driver)->writer_options;
	    last_writer_options->flush_lines = 0;
	  }
break;
case 189:
#line 785 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 193:
#line 795 "cfg-grammar.y"
{ affile_dd_set_file_uid(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 194:
#line 796 "cfg-grammar.y"
{ affile_dd_set_file_gid(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 195:
#line 797 "cfg-grammar.y"
{ affile_dd_set_file_perm(last_driver, yyvsp[-1].num); }
break;
case 196:
#line 801 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 197:
#line 802 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 198:
#line 803 "cfg-grammar.y"
{ last_addr_family = AF_INET; }
break;
case 199:
#line 803 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 200:
#line 804 "cfg-grammar.y"
{ last_addr_family = AF_INET; }
break;
case 201:
#line 804 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 202:
#line 805 "cfg-grammar.y"
{ last_addr_family = AF_INET6; }
break;
case 203:
#line 805 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 204:
#line 806 "cfg-grammar.y"
{ last_addr_family = AF_INET6; }
break;
case 205:
#line 806 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 206:
#line 811 "cfg-grammar.y"
{ 
	    last_driver = afunix_dd_new(yyvsp[0].cptr, AFSOCKET_DGRAM);
	    free(yyvsp[0].cptr);
	    last_writer_options = &((AFSocketDestDriver *) last_driver)->writer_options;
	    last_sock_options = &((AFUnixDestDriver *) last_driver)->sock_options;
	  }
break;
case 207:
#line 817 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 208:
#line 822 "cfg-grammar.y"
{ 
	    last_driver = afunix_dd_new(yyvsp[0].cptr, AFSOCKET_STREAM);
	    free(yyvsp[0].cptr);
	    last_writer_options = &((AFSocketDestDriver *) last_driver)->writer_options;
	    last_sock_options = &((AFUnixDestDriver *) last_driver)->sock_options;
	  }
break;
case 209:
#line 828 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 215:
#line 844 "cfg-grammar.y"
{ 
	    last_driver = afinet_dd_new(last_addr_family,
			yyvsp[0].cptr, 514,
			AFSOCKET_DGRAM);
	    free(yyvsp[0].cptr);
	    last_writer_options = &((AFSocketDestDriver *) last_driver)->writer_options;
	    last_sock_options = &((AFInetDestDriver *) last_driver)->sock_options.super;
	  }
break;
case 216:
#line 852 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 219:
#line 862 "cfg-grammar.y"
{ afinet_dd_set_localip(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 220:
#line 863 "cfg-grammar.y"
{ afinet_dd_set_localport(last_driver, yyvsp[-1].cptr, afinet_dd_get_proto_name(last_driver)); free(yyvsp[-1].cptr); }
break;
case 221:
#line 864 "cfg-grammar.y"
{ afinet_dd_set_destport(last_driver, yyvsp[-1].cptr, afinet_dd_get_proto_name(last_driver)); free(yyvsp[-1].cptr); }
break;
case 222:
#line 865 "cfg-grammar.y"
{ afinet_dd_set_destport(last_driver, yyvsp[-1].cptr, afinet_dd_get_proto_name(last_driver)); free(yyvsp[-1].cptr); }
break;
case 227:
#line 873 "cfg-grammar.y"
{ afinet_dd_set_spoof_source(last_driver, yyvsp[-1].num); }
break;
case 228:
#line 878 "cfg-grammar.y"
{ 
	    last_driver = afinet_dd_new(last_addr_family,
			yyvsp[0].cptr, 514,
			AFSOCKET_STREAM); 
	    free(yyvsp[0].cptr);
	    last_writer_options = &((AFSocketDestDriver *) last_driver)->writer_options;
	    last_sock_options = &((AFInetDestDriver *) last_driver)->sock_options.super;
	  }
break;
case 229:
#line 886 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 233:
#line 897 "cfg-grammar.y"
{
#if ENABLE_TLS
	    last_tls_context = tls_context_new(TM_CLIENT);
#endif
	  }
break;
case 234:
#line 903 "cfg-grammar.y"
{ 
#if ENABLE_SSL
	    afsocket_dd_set_tls_context(last_driver, last_tls_context); 
#endif
          }
break;
case 235:
#line 911 "cfg-grammar.y"
{ afsocket_dd_set_keep_alive(last_driver, yyvsp[-1].num); }
break;
case 236:
#line 916 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 237:
#line 920 "cfg-grammar.y"
{
            last_driver = afinet_dd_new(last_addr_family, yyvsp[0].cptr, 601, AFSOCKET_STREAM | AFSOCKET_SYSLOG_PROTOCOL);
	    last_writer_options = &((AFSocketDestDriver *) last_driver)->writer_options;
	    last_sock_options = &((AFInetDestDriver *) last_driver)->sock_options.super;
	    free(yyvsp[0].cptr);
	  }
break;
case 238:
#line 926 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 242:
#line 937 "cfg-grammar.y"
{ afinet_dd_set_transport(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 243:
#line 938 "cfg-grammar.y"
{ afinet_dd_set_transport(last_driver, "tcp"); }
break;
case 244:
#line 939 "cfg-grammar.y"
{ afinet_dd_set_transport(last_driver, "udp"); }
break;
case 245:
#line 940 "cfg-grammar.y"
{ afinet_dd_set_transport(last_driver, "tls"); }
break;
case 246:
#line 941 "cfg-grammar.y"
{ afinet_dd_set_spoof_source(last_driver, yyvsp[-1].num); }
break;
case 247:
#line 943 "cfg-grammar.y"
{
#if ENABLE_SSL
	    last_tls_context = tls_context_new(TM_CLIENT);
#endif
	  }
break;
case 248:
#line 949 "cfg-grammar.y"
{ 
#if ENABLE_SSL
	    afsocket_dd_set_tls_context(last_driver, last_tls_context); 
#endif
          }
break;
case 249:
#line 958 "cfg-grammar.y"
{ yyval.ptr = afuser_dd_new(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 250:
#line 962 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 251:
#line 967 "cfg-grammar.y"
{ 
	    last_driver = afprogram_dd_new(yyvsp[0].cptr); 
	    free(yyvsp[0].cptr); 
	    last_writer_options = &((AFProgramDestDriver *) last_driver)->writer_options;
	  }
break;
case 252:
#line 972 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 253:
#line 978 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; }
break;
case 254:
#line 983 "cfg-grammar.y"
{
            #if ENABLE_SQL	
            last_driver = afsql_dd_new();
            #endif /* ENABLE_SQL */
          }
break;
case 255:
#line 988 "cfg-grammar.y"
{ yyval.ptr = last_driver; }
break;
case 258:
#line 997 "cfg-grammar.y"
{ 
#if ENABLE_SQL 
}
break;
case 259:
#line 1000 "cfg-grammar.y"
{ afsql_dd_set_type(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 260:
#line 1001 "cfg-grammar.y"
{ afsql_dd_set_host(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 261:
#line 1002 "cfg-grammar.y"
{ afsql_dd_set_port(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 262:
#line 1003 "cfg-grammar.y"
{ afsql_dd_set_user(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 263:
#line 1004 "cfg-grammar.y"
{ afsql_dd_set_password(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 264:
#line 1005 "cfg-grammar.y"
{ afsql_dd_set_database(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 265:
#line 1006 "cfg-grammar.y"
{ afsql_dd_set_table(last_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 266:
#line 1007 "cfg-grammar.y"
{ afsql_dd_set_columns(last_driver, yyvsp[-1].ptr); }
break;
case 267:
#line 1008 "cfg-grammar.y"
{ afsql_dd_set_indexes(last_driver, yyvsp[-1].ptr); }
break;
case 268:
#line 1009 "cfg-grammar.y"
{ afsql_dd_set_values(last_driver, yyvsp[-1].ptr); }
break;
case 269:
#line 1010 "cfg-grammar.y"
{ afsql_dd_set_mem_fifo_size(last_driver, yyvsp[-1].num); }
break;
case 270:
#line 1011 "cfg-grammar.y"
{ afsql_dd_set_disk_fifo_size(last_driver, yyvsp[-1].num); }
break;
case 271:
#line 1012 "cfg-grammar.y"
{ afsql_dd_set_frac_digits(last_driver, yyvsp[-1].num); }
break;
case 272:
#line 1013 "cfg-grammar.y"
{ afsql_dd_set_time_zone_string(last_driver,yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 273:
#line 1015 "cfg-grammar.y"
{ 
#endif /* ENABLE_SQL */ 
}
break;
case 276:
#line 1028 "cfg-grammar.y"
{ last_writer_options->options = yyvsp[-1].num; }
break;
case 277:
#line 1029 "cfg-grammar.y"
{ last_writer_options->mem_fifo_size = yyvsp[-1].num; }
break;
case 278:
#line 1030 "cfg-grammar.y"
{ last_writer_options->flush_lines = yyvsp[-1].num; }
break;
case 279:
#line 1031 "cfg-grammar.y"
{ last_writer_options->flush_timeout = yyvsp[-1].num; }
break;
case 280:
#line 1032 "cfg-grammar.y"
{ last_writer_options->suppress = yyvsp[-1].num; }
break;
case 281:
#line 1033 "cfg-grammar.y"
{ 
	                                          last_writer_options->template = cfg_check_inline_template(configuration, yyvsp[-1].cptr);
                                                  if (!cfg_check_template(last_writer_options->template))
	                                            {
	                                              YYERROR;
	                                            }
	                                          free(yyvsp[-1].cptr);
	                                        }
break;
case 282:
#line 1041 "cfg-grammar.y"
{ log_writer_options_set_template_escape(last_writer_options, yyvsp[-1].num); }
break;
case 283:
#line 1042 "cfg-grammar.y"
{ last_writer_options->time_zone_string = g_strdup(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 284:
#line 1043 "cfg-grammar.y"
{ last_writer_options->ts_format = cfg_ts_format_value(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 285:
#line 1044 "cfg-grammar.y"
{ last_writer_options->frac_digits = yyvsp[-1].num; }
break;
case 286:
#line 1045 "cfg-grammar.y"
{ last_writer_options->throttle = yyvsp[-1].num; }
break;
case 287:
#line 1049 "cfg-grammar.y"
{ yyval.num = log_writer_options_lookup_flag(yyvsp[-1].cptr) | yyvsp[0].num; free(yyvsp[-1].cptr); }
break;
case 288:
#line 1050 "cfg-grammar.y"
{ yyval.num = 0; }
break;
case 289:
#line 1055 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-2].ptr; }
break;
case 290:
#line 1056 "cfg-grammar.y"
{ yyval.ptr = NULL; }
break;
case 291:
#line 1060 "cfg-grammar.y"
{ configuration->mark_freq = yyvsp[-1].num; }
break;
case 292:
#line 1061 "cfg-grammar.y"
{ configuration->stats_freq = yyvsp[-1].num; }
break;
case 293:
#line 1062 "cfg-grammar.y"
{ configuration->stats_level = yyvsp[-1].num; }
break;
case 294:
#line 1063 "cfg-grammar.y"
{ configuration->flush_lines = yyvsp[-1].num; }
break;
case 295:
#line 1064 "cfg-grammar.y"
{ configuration->flush_timeout = yyvsp[-1].num; }
break;
case 296:
#line 1065 "cfg-grammar.y"
{ configuration->chain_hostnames = yyvsp[-1].num; }
break;
case 297:
#line 1066 "cfg-grammar.y"
{ configuration->normalize_hostnames = yyvsp[-1].num; }
break;
case 298:
#line 1067 "cfg-grammar.y"
{ configuration->keep_hostname = yyvsp[-1].num; }
break;
case 299:
#line 1068 "cfg-grammar.y"
{ configuration->check_hostname = yyvsp[-1].num; }
break;
case 300:
#line 1069 "cfg-grammar.y"
{ cfg_bad_hostname_set(configuration, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 301:
#line 1070 "cfg-grammar.y"
{ configuration->use_time_recvd = yyvsp[-1].num; }
break;
case 302:
#line 1071 "cfg-grammar.y"
{ configuration->use_fqdn = yyvsp[-1].num; }
break;
case 303:
#line 1072 "cfg-grammar.y"
{ configuration->use_dns = yyvsp[-1].num; }
break;
case 304:
#line 1073 "cfg-grammar.y"
{ configuration->time_reopen = yyvsp[-1].num; }
break;
case 305:
#line 1074 "cfg-grammar.y"
{ configuration->time_reap = yyvsp[-1].num; }
break;
case 306:
#line 1076 "cfg-grammar.y"
{ 
		  configuration->time_sleep = yyvsp[-1].num; 
		  if (yyvsp[-1].num > 500) 
		    { 
		      msg_notice("The value specified for time_sleep is too large", evt_tag_int("time_sleep", yyvsp[-1].num), NULL);
		      configuration->time_sleep = 500;
		    }
		}
break;
case 307:
#line 1084 "cfg-grammar.y"
{ configuration->log_fifo_size = yyvsp[-1].num; }
break;
case 308:
#line 1085 "cfg-grammar.y"
{ configuration->log_iw_size = yyvsp[-1].num; }
break;
case 309:
#line 1086 "cfg-grammar.y"
{ configuration->log_fetch_limit = yyvsp[-1].num; }
break;
case 310:
#line 1087 "cfg-grammar.y"
{ configuration->log_msg_size = yyvsp[-1].num; }
break;
case 311:
#line 1088 "cfg-grammar.y"
{ configuration->keep_timestamp = yyvsp[-1].num; }
break;
case 312:
#line 1089 "cfg-grammar.y"
{ configuration->ts_format = cfg_ts_format_value(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 313:
#line 1090 "cfg-grammar.y"
{ configuration->frac_digits = yyvsp[-1].num; }
break;
case 314:
#line 1091 "cfg-grammar.y"
{ /* ignored */; }
break;
case 315:
#line 1092 "cfg-grammar.y"
{ /* ignored */; }
break;
case 316:
#line 1093 "cfg-grammar.y"
{ configuration->create_dirs = yyvsp[-1].num; }
break;
case 317:
#line 1094 "cfg-grammar.y"
{ cfg_file_owner_set(configuration, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 318:
#line 1095 "cfg-grammar.y"
{ cfg_file_group_set(configuration, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 319:
#line 1096 "cfg-grammar.y"
{ cfg_file_perm_set(configuration, yyvsp[-1].num); }
break;
case 320:
#line 1097 "cfg-grammar.y"
{ cfg_dir_owner_set(configuration, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 321:
#line 1098 "cfg-grammar.y"
{ cfg_dir_group_set(configuration, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 322:
#line 1099 "cfg-grammar.y"
{ cfg_dir_perm_set(configuration, yyvsp[-1].num); }
break;
case 323:
#line 1100 "cfg-grammar.y"
{ configuration->use_dns_cache = yyvsp[-1].num; }
break;
case 324:
#line 1101 "cfg-grammar.y"
{ configuration->dns_cache_size = yyvsp[-1].num; }
break;
case 325:
#line 1102 "cfg-grammar.y"
{ configuration->dns_cache_expire = yyvsp[-1].num; }
break;
case 326:
#line 1104 "cfg-grammar.y"
{ configuration->dns_cache_expire_failed = yyvsp[-1].num; }
break;
case 327:
#line 1105 "cfg-grammar.y"
{ configuration->dns_cache_hosts = g_strdup(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 328:
#line 1106 "cfg-grammar.y"
{ configuration->file_template_name = g_strdup(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 329:
#line 1107 "cfg-grammar.y"
{ configuration->proto_template_name = g_strdup(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 330:
#line 1108 "cfg-grammar.y"
{ configuration->recv_time_zone_string = g_strdup(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 331:
#line 1109 "cfg-grammar.y"
{ configuration->send_time_zone_string = g_strdup(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 334:
#line 1119 "cfg-grammar.y"
{ 
#if ENABLE_SSL
}
break;
case 335:
#line 1124 "cfg-grammar.y"
{ 
	    last_tls_context->verify_mode = tls_lookup_verify_mode(yyvsp[-1].cptr); 
            free(yyvsp[-1].cptr); 
          }
break;
case 336:
#line 1129 "cfg-grammar.y"
{ 
	    last_tls_context->key_file = g_strdup(yyvsp[-1].cptr); 
            free(yyvsp[-1].cptr);
          }
break;
case 337:
#line 1134 "cfg-grammar.y"
{ 
	    last_tls_context->cert_file = g_strdup(yyvsp[-1].cptr); 
            free(yyvsp[-1].cptr);
          }
break;
case 338:
#line 1139 "cfg-grammar.y"
{ 
	    last_tls_context->ca_dir = g_strdup(yyvsp[-1].cptr); 
            free(yyvsp[-1].cptr);
          }
break;
case 339:
#line 1144 "cfg-grammar.y"
{ 
	    last_tls_context->crl_dir = g_strdup(yyvsp[-1].cptr); 
            free(yyvsp[-1].cptr);
          }
break;
case 340:
#line 1149 "cfg-grammar.y"
{ 
            tls_session_set_trusted_fingerprints(last_tls_context, yyvsp[-1].ptr); 
          }
break;
case 341:
#line 1153 "cfg-grammar.y"
{ 
            tls_session_set_trusted_dn(last_tls_context, yyvsp[-1].ptr); 
          }
break;
case 342:
#line 1156 "cfg-grammar.y"
{
#endif
}
break;
case 343:
#line 1164 "cfg-grammar.y"
{ yyval.node = yyvsp[0].node; if (!yyvsp[0].node) return 1; }
break;
case 344:
#line 1165 "cfg-grammar.y"
{ yyvsp[0].node->comp = !(yyvsp[0].node->comp); yyval.node = yyvsp[0].node; }
break;
case 345:
#line 1166 "cfg-grammar.y"
{ yyval.node = fop_or_new(yyvsp[-2].node, yyvsp[0].node); }
break;
case 346:
#line 1167 "cfg-grammar.y"
{ yyval.node = fop_and_new(yyvsp[-2].node, yyvsp[0].node); }
break;
case 347:
#line 1168 "cfg-grammar.y"
{ yyval.node = yyvsp[-1].node; }
break;
case 348:
#line 1172 "cfg-grammar.y"
{ yyval.node = filter_facility_new(yyvsp[-1].num);  }
break;
case 349:
#line 1173 "cfg-grammar.y"
{ yyval.node = filter_facility_new(0x80000000 | yyvsp[-1].num); }
break;
case 350:
#line 1174 "cfg-grammar.y"
{ yyval.node = filter_level_new(yyvsp[-1].num); }
break;
case 351:
#line 1175 "cfg-grammar.y"
{ yyval.node = filter_call_new(yyvsp[-1].cptr, configuration); free(yyvsp[-1].cptr); }
break;
case 352:
#line 1176 "cfg-grammar.y"
{ yyval.node = filter_netmask_new(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 353:
#line 1178 "cfg-grammar.y"
{ 
	    last_re_filter = (FilterRE *) filter_re_new(LOG_MESSAGE_BUILTIN_FIELD(PROGRAM)); 
          }
break;
case 354:
#line 1182 "cfg-grammar.y"
{
            if(!filter_re_set_regexp(last_re_filter, yyvsp[-3].cptr))
              YYERROR;
            free(yyvsp[-3].cptr); 

            yyval.node = &last_re_filter->super;
          }
break;
case 355:
#line 1190 "cfg-grammar.y"
{
	    last_re_filter = (FilterRE *) filter_re_new(LOG_MESSAGE_BUILTIN_FIELD(HOST)); 
          }
break;
case 356:
#line 1194 "cfg-grammar.y"
{
            if(!filter_re_set_regexp(last_re_filter, yyvsp[-3].cptr))
              YYERROR;
            free(yyvsp[-3].cptr); 
            
            yyval.node = &last_re_filter->super;
          }
break;
case 357:
#line 1202 "cfg-grammar.y"
{ 
	    last_re_filter = (FilterRE *) filter_match_new(); 
	  }
break;
case 358:
#line 1206 "cfg-grammar.y"
{
            if(!filter_re_set_regexp(last_re_filter, yyvsp[-3].cptr))
              YYERROR;
            free(yyvsp[-3].cptr); 
            yyval.node = &last_re_filter->super;
            
            if (last_re_filter->value_name == 0)
              {
                static gboolean warn_written = FALSE;
                
                if (!warn_written)
                  {
                    msg_warning("WARNING: the match() filter without the use of the value() option is deprecated and hinders performance, please update your configuration",
                                NULL);
                    warn_written = TRUE;
                  }
              }
          }
break;
case 359:
#line 1225 "cfg-grammar.y"
{
	    last_re_filter = (FilterRE *) filter_re_new(LOG_MESSAGE_BUILTIN_FIELD(MESSAGE)); 
          }
break;
case 360:
#line 1229 "cfg-grammar.y"
{
            if(!filter_re_set_regexp(last_re_filter, yyvsp[-3].cptr))
              YYERROR;
	    free(yyvsp[-3].cptr); 
            yyval.node = &last_re_filter->super;
          }
break;
case 361:
#line 1236 "cfg-grammar.y"
{
	    last_re_filter = (FilterRE *) filter_re_new(LOG_MESSAGE_BUILTIN_FIELD(SOURCE)); 
            filter_re_set_matcher(last_re_filter, log_matcher_string_new());
          }
break;
case 362:
#line 1241 "cfg-grammar.y"
{
            if(!filter_re_set_regexp(last_re_filter, yyvsp[-3].cptr))
              YYERROR;
	    free(yyvsp[-3].cptr); 
            yyval.node = &last_re_filter->super;
          }
break;
case 366:
#line 1256 "cfg-grammar.y"
{ last_re_filter->value_name = log_msg_translate_value_name(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 369:
#line 1266 "cfg-grammar.y"
{ 
            filter_re_set_matcher(last_re_filter, log_matcher_new(yyvsp[-1].cptr));
            free(yyvsp[-1].cptr); 
          }
break;
case 370:
#line 1270 "cfg-grammar.y"
{ filter_re_set_flags(last_re_filter, yyvsp[-1].num); }
break;
case 371:
#line 1274 "cfg-grammar.y"
{ yyval.num = log_matcher_lookup_flag(yyvsp[-1].cptr) | yyvsp[0].num; free(yyvsp[-1].cptr); }
break;
case 372:
#line 1275 "cfg-grammar.y"
{ yyval.num = 0; }
break;
case 373:
#line 1280 "cfg-grammar.y"
{ yyval.num = yyvsp[-1].num | yyvsp[0].num; }
break;
case 374:
#line 1281 "cfg-grammar.y"
{ yyval.num = yyvsp[0].num; }
break;
case 375:
#line 1286 "cfg-grammar.y"
{ 
	    int n = syslog_name_lookup_facility_by_name(yyvsp[0].cptr);
	    if (n == -1)
	      {
	        msg_error("Warning: Unknown facility", 
	                  evt_tag_str("facility", yyvsp[0].cptr),
	                  NULL);
	        yyval.num = 0;
	      }
	    else
	      yyval.num = (1 << n); 
	    free(yyvsp[0].cptr); 
	  }
break;
case 376:
#line 1302 "cfg-grammar.y"
{ yyval.num = yyvsp[-1].num | yyvsp[0].num; }
break;
case 377:
#line 1303 "cfg-grammar.y"
{ yyval.num = yyvsp[0].num; }
break;
case 378:
#line 1308 "cfg-grammar.y"
{ 
	    int r1, r2;
	    r1 = syslog_name_lookup_level_by_name(yyvsp[-2].cptr);
	    if (r1 == -1)
	      msg_error("Warning: Unknown priority level",
                        evt_tag_str("priority", yyvsp[-2].cptr),
                        NULL);
	    r2 = syslog_name_lookup_level_by_name(yyvsp[0].cptr);
	    if (r2 == -1)
	      msg_error("Warning: Unknown priority level",
                        evt_tag_str("priority", yyvsp[-2].cptr),
                        NULL);
	    if (r1 != -1 && r2 != -1)
	      yyval.num = syslog_make_range(r1, r2); 
	    else
	      yyval.num = 0;
	    free(yyvsp[-2].cptr); 
	    free(yyvsp[0].cptr); 
	  }
break;
case 379:
#line 1328 "cfg-grammar.y"
{ 
	    int n = syslog_name_lookup_level_by_name(yyvsp[0].cptr); 
	    if (n == -1)
	      {
	        msg_error("Warning: Unknown priority level",
                          evt_tag_str("priority", yyvsp[0].cptr),
                          NULL);
	        yyval.num = 0;
	      }
	    else
	      yyval.num = 1 << n;
	    free(yyvsp[0].cptr); 
	  }
break;
case 380:
#line 1345 "cfg-grammar.y"
{ 
            last_parser = (LogParser *) log_csv_parser_new(); 
          }
break;
case 381:
#line 1349 "cfg-grammar.y"
{ yyval.ptr = last_parser; }
break;
case 382:
#line 1351 "cfg-grammar.y"
{
            last_parser = (LogParser *) log_db_parser_new();
          }
break;
case 383:
#line 1355 "cfg-grammar.y"
{ yyval.ptr = last_parser; }
break;
case 386:
#line 1365 "cfg-grammar.y"
{ log_db_parser_set_db_file(((LogDBParser *) last_parser), yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 388:
#line 1370 "cfg-grammar.y"
{ log_column_parser_set_columns((LogColumnParser *) last_parser, yyvsp[-1].ptr); }
break;
case 389:
#line 1374 "cfg-grammar.y"
{ 
                                                  LogTemplate *template = cfg_check_inline_template(configuration, yyvsp[-1].cptr);
                                                  if (!cfg_check_template(template))
                                                    {
                                                      YYERROR;
                                                    }
                                                  log_parser_set_template(last_parser, template); 
                                                  free(yyvsp[-1].cptr); 
                                                }
break;
case 393:
#line 1393 "cfg-grammar.y"
{ log_csv_parser_set_flags((LogColumnParser *) last_parser, yyvsp[-1].num); }
break;
case 394:
#line 1394 "cfg-grammar.y"
{ log_csv_parser_set_delimiters((LogColumnParser *) last_parser, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 395:
#line 1395 "cfg-grammar.y"
{ log_csv_parser_set_quotes((LogColumnParser *) last_parser, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 396:
#line 1396 "cfg-grammar.y"
{ log_csv_parser_set_quote_pairs((LogColumnParser *) last_parser, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 397:
#line 1397 "cfg-grammar.y"
{ log_csv_parser_set_null_value((LogColumnParser *) last_parser, yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 398:
#line 1401 "cfg-grammar.y"
{ yyval.num = log_csv_parser_lookup_flag(yyvsp[-1].cptr) | yyvsp[0].num; free(yyvsp[-1].cptr); }
break;
case 399:
#line 1402 "cfg-grammar.y"
{ yyval.num = 0; }
break;
case 400:
#line 1406 "cfg-grammar.y"
{ yyval.ptr = g_list_reverse(yyvsp[0].ptr); }
break;
case 401:
#line 1410 "cfg-grammar.y"
{ yyval.ptr = g_list_append(yyvsp[0].ptr, yyvsp[-1].ptr); }
break;
case 402:
#line 1411 "cfg-grammar.y"
{ yyval.ptr = NULL; }
break;
case 403:
#line 1416 "cfg-grammar.y"
{ 
            last_rewrite = log_rewrite_subst_new(yyvsp[0].cptr); 
            free(yyvsp[0].cptr);  
          }
break;
case 404:
#line 1421 "cfg-grammar.y"
{ 
            if(!log_rewrite_set_regexp(last_rewrite, yyvsp[-5].cptr))
              YYERROR;
            free(yyvsp[-5].cptr);
            yyval.ptr = last_rewrite; 
          }
break;
case 405:
#line 1428 "cfg-grammar.y"
{
            last_rewrite = log_rewrite_set_new(yyvsp[0].cptr); 
            free(yyvsp[0].cptr);
          }
break;
case 406:
#line 1432 "cfg-grammar.y"
{ yyval.ptr = last_rewrite; }
break;
case 409:
#line 1441 "cfg-grammar.y"
{ last_rewrite->value_name = log_msg_translate_value_name(yyvsp[-1].cptr); free(yyvsp[-1].cptr); }
break;
case 410:
#line 1443 "cfg-grammar.y"
{ 
            log_rewrite_set_matcher(last_rewrite, log_matcher_new(yyvsp[-1].cptr));
            free(yyvsp[-1].cptr); 
          }
break;
case 411:
#line 1447 "cfg-grammar.y"
{ log_rewrite_set_flags(last_rewrite, yyvsp[-1].num); }
break;
case 412:
#line 1451 "cfg-grammar.y"
{ yyval.num = 1; }
break;
case 413:
#line 1452 "cfg-grammar.y"
{ yyval.num = 0; }
break;
case 414:
#line 1453 "cfg-grammar.y"
{ yyval.num = yyvsp[0].num; }
break;
case 415:
#line 1457 "cfg-grammar.y"
{ yyval.num = yyvsp[0].num; }
break;
case 416:
#line 1458 "cfg-grammar.y"
{ yyval.num = 2; }
break;
case 419:
#line 1467 "cfg-grammar.y"
{ yyval.cptr = yyvsp[0].cptr; }
break;
case 420:
#line 1468 "cfg-grammar.y"
{ char buf[32]; snprintf(buf, sizeof(buf), "%" G_GINT64_FORMAT, yyvsp[0].num); yyval.cptr = strdup(buf); }
break;
case 421:
#line 1471 "cfg-grammar.y"
{ yyval.ptr = g_list_reverse(yyvsp[0].ptr); }
break;
case 422:
#line 1475 "cfg-grammar.y"
{ yyval.ptr = g_list_append(yyvsp[0].ptr, g_strdup(yyvsp[-1].cptr)); free(yyvsp[-1].cptr); }
break;
case 423:
#line 1476 "cfg-grammar.y"
{ yyval.ptr = NULL; }
break;
#line 3448 "cfg-grammar.c"
    }
    yyssp -= yym;
    yystate = *yyssp;
    yyvsp -= yym;
    yym = yylhs[yyn];
    if (yystate == 0 && yym == 0)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: after reduction, shifting from state 0 to\
 state %d\n", YYPREFIX, YYFINAL);
#endif
        yystate = YYFINAL;
        *++yyssp = YYFINAL;
        *++yyvsp = yyval;
        if (yychar < 0)
        {
            if ((yychar = yylex()) < 0) yychar = 0;
#if YYDEBUG
            if (yydebug)
            {
                yys = 0;
                if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
                if (!yys) yys = "illegal-symbol";
                printf("%sdebug: state %d, reading %d (%s)\n",
                        YYPREFIX, YYFINAL, yychar, yys);
            }
#endif
        }
        if (yychar == 0) goto yyaccept;
        goto yyloop;
    }
    if ((yyn = yygindex[yym]) && (yyn += yystate) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yystate)
        yystate = yytable[yyn];
    else
        yystate = yydgoto[yym];
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: after reduction, shifting from state %d \
to state %d\n", YYPREFIX, *yyssp, yystate);
#endif
    if (yyssp >= yysslim && yygrowstack())
    {
        goto yyoverflow;
    }
    *++yyssp = yystate;
    *++yyvsp = yyval;
    goto yyloop;
yyoverflow:
    yyerror("yacc stack overflow");
yyabort:
    return (1);
yyaccept:
    return (0);
}
